@@ -26,17 +26,8 @@
 extern "C" {
 #endif	
 
-//#include <glib-1.2/glib.h>
-	
-
-#include "main/lists.h"
-
-#include "backend/mgr.hh"
-#include "backend/key.hh"
 #include "backend/config.hh"
-#include "backend/module.hh"
-#include "backend/tree.hh"
-	
+		
 void backend_init(void);
 void backend_shutdown(int save_properties);
 const char *backend_get_sword_version(void);
