@@ -65,7 +65,7 @@ gui_create_about_gnomesword(void)
     "Andy Piper",
     NULL
   };
-  gchar *translators = "Jan Paul Schmidt\nJorge Chacon\nDominique Corbex\nZdenko Podobn\nPavlo Bohmat\303\275";
+  gchar *translators = "Jan Paul Schmidt\nJorge Chacon\nDominique Corbex\nZdenko Podobn\nPavlo Bohmat";
   GdkPixbuf *about1_logo_pixbuf;
   GtkWidget *about1;
   GError *error = NULL;
