@@ -47,9 +47,10 @@
 #include "gui/widgets.h"
 
 #include "main/settings.h"
+#include "main/sidebar.h"
 #include "main/sword.h"
-#include "main/key.h"
 #include "main/xml.h"
+#include "main/module_dialogs.h"
 
 
 
@@ -57,6 +58,8 @@ BOOKMARK_MENU menu;
 
 gboolean bookmarks_changed;
 
+//extern GtkTreeView *bookmark_tree;
+
 static void save_bookmarks(GtkMenuItem * menuitem, gpointer user_data);
 
 /******************************************************************************
@@ -82,13 +85,20 @@ static void parse_treeview(xmlNodePtr parent, GtkTreeIter * tree_parent)
 	gchar *caption = NULL;
 	gchar *key = NULL;
 	gchar *module = NULL;
+	gchar *mod_desc = NULL;
+	gchar *description = NULL;
 	
 	gtk_tree_model_iter_children(GTK_TREE_MODEL(model), &child,
                                              tree_parent);
 	
 	do {
 		gtk_tree_model_get(GTK_TREE_MODEL(model), &child,
-			   2, &caption, 3, &key, 4, &module, -1);
+			   		2, &caption, 
+					3, &key, 
+					4, &module, 
+					5, &mod_desc, 
+					6, &description,
+					-1);
 		if(gtk_tree_model_iter_has_child(GTK_TREE_MODEL(model), 
 							&child)) {
 			cur_node = xml_add_folder_to_parent(parent, 
@@ -98,13 +108,16 @@ static void parse_treeview(xmlNodePtr parent, GtkTreeIter * tree_parent)
 		}
 		else 
 			xml_add_bookmark_to_parent(parent, 
-						caption,
+						description,
 						key,
-						module);
+						module,
+						mod_desc);
 		
 		g_free(caption);
 		g_free(key);
 		g_free(module);	
+		g_free(mod_desc);
+		g_free(description);
 	} while(gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &child));
 }
 
@@ -192,6 +205,8 @@ static void save_treeview_to_xml_bookmarks(GtkTreeIter * iter, gchar * filename)
 	gchar *caption = NULL;
 	gchar *key = NULL;
 	gchar *module = NULL;
+	gchar *mod_desc = NULL;
+	gchar *description = NULL;
 	
 	if (!bookmarks_changed) 
 		return;
@@ -210,19 +225,27 @@ static void save_treeview_to_xml_bookmarks(GtkTreeIter * iter, gchar * filename)
 	
 	do {
 		gtk_tree_model_get(GTK_TREE_MODEL(model), iter,
-			   2, &caption, 3, &key, 4, &module, -1);
+			   		2, &caption, 
+					3, &key, 
+					4, &module, 
+					5, &mod_desc, 
+					6, &description, 
+					-1);
 		if( gtk_tree_model_iter_has_child(GTK_TREE_MODEL(model),iter)) {
 			cur_node = xml_add_folder_to_parent(root_node, caption);
 			parse_treeview(cur_node, iter);
 		}
 		else 		
 			xml_add_bookmark_to_parent(root_node,  
-						caption,
+						description,
 						key,
-						module);
+						module,
+						mod_desc);
 		g_free(caption);
 		g_free(key);
 		g_free(module);	
+		g_free(mod_desc);
+		g_free(description);	
 	} while(gtk_tree_model_iter_next(GTK_TREE_MODEL(model),iter));
 	
 	xmlSaveFormatFile(xml_filename, root_doc,1);
@@ -253,8 +276,7 @@ static void save_treeview_to_xml_bookmarks(GtkTreeIter * iter, gchar * filename)
 static void add_item_to_tree(GtkTreeIter *iter,GtkTreeIter *parent, 
 							BOOKMARK_DATA * data)
 {
-	gtk_tree_store_append(GTK_TREE_STORE(model), iter,
-			      parent);
+	gtk_tree_store_append(GTK_TREE_STORE(model), iter, parent);
 	
 		gtk_tree_store_set(GTK_TREE_STORE(model), iter, 
 			   COL_OPEN_PIXBUF, data->opened,
@@ -262,93 +284,12 @@ static void add_item_to_tree(GtkTreeIter *iter,GtkTreeIter *parent,
 			   COL_CAPTION, data->caption, 
 			   COL_KEY, data->key,
 			   COL_MODULE, data->module,
+			   COL_MODULE_DESC, data->module_desc,
+			   COL_DESCRIPTION, data->description,
 			   -1);
 }
 
-/******************************************************************************
- * Name
- *   
- *
- * Synopsis
- *   #include "gui/bookmarks_menu.h"
- *
- *   
- *
- * Description
- *   called gnome_request_dialog to return information from user
- *
- * Return value
- *   void
- */
 
-static void string_callback(gchar * str, gpointer data)
-{
-/*	gchar *text[3];
-	gchar buf[80], buf2[80];
-	gint length, i = 0, j = 0;
-	GtkCList *clist;
-	GtkCTreeNode *first_child;
-
-
-	if ((str == NULL) || (strlen(str) == 0)) {
-		(gchar *) data = NULL;
-	} else {
-		GtkCTreeNode *newnode;
-	
-		switch (GPOINTER_TO_INT(data)) {
-		case 0:
-			text[0] = str;
-			text[1] = "GROUP";
-			text[2] = "GROUP";
-			first_child
-			    = GTK_CTREE_ROW(selected_node)->children;
-			newnode = gtk_ctree_insert_node(p_bmtree->ctree,
-							selected_node,
-							first_child,
-							text, 3,
-							pixmap1, mask1,
-							pixmap2, mask2,
-							FALSE, FALSE);
-			gtk_ctree_sort_node(bmtree.ctree,
-					    selected_node);
-			gtk_ctree_select(p_bmtree->ctree, newnode);
-			gtk_ctree_expand(p_bmtree->ctree,
-					 selected_node);
-			break;
-		case 1:
-			clist = GTK_CLIST(p_bmtree->ctree);
-			gtk_clist_select_row(clist, 0, 0);
-			sprintf(buf, "%s", str);
-			text[0] = str;
-			length = strlen(buf);
-			if (length > 29)
-				length = 29;
-			while (i < length) {
-				if (isalpha(buf[i])) {
-					buf2[j] = buf[i];
-					++j;
-				}
-				buf2[j] = '\0';
-				++i;
-			}
-			sprintf(buf, "%s%s", buf2, ".conf");
-			text[1] = buf;
-			text[2] = "ROOT";
-			newrootnode =
-			    gtk_ctree_insert_node(p_bmtree->ctree,
-						  selected_node, NULL,
-						  text, 3, pixmap1,
-						  mask1, pixmap2, mask2,
-						  FALSE, FALSE);
-			gtk_ctree_sort_node(bmtree.ctree,
-					    selected_node);
-			gtk_ctree_select(p_bmtree->ctree, newrootnode);
-			break;
-		}
-	}
-	*/
-
-}
 /******************************************************************************
  * Name
  *   goto_bookmark
@@ -366,31 +307,26 @@ static void string_callback(gchar * str, gpointer data)
  *   void
  */
 
-static void goto_bookmark(gchar * mod_name, gchar * key)
+static void goto_bookmark(gchar * url)
 {
 	gint module_type;
-
+	
 	if (use_dialog) {
-		module_type = get_mod_type(mod_name);
+		module_type = main_main_get_mod_type_from_url(url);
 		switch (module_type) {
 		case TEXT_TYPE:
-			gui_bibletext_dialog_goto_bookmark(mod_name,
-							   key);
-			break;
 		case COMMENTARY_TYPE:
-			gui_commentary_dialog_goto_bookmark(mod_name,
-							    key);
+			main_dialog_goto_bookmark(url);
 			break;
 		case DICTIONARY_TYPE:
-			gui_dictionary_dialog_goto_bookmark(mod_name,
-							    key);
+			//gui_dictionary_dialog_goto_bookmark(mod_name, key);
 			break;
 		case BOOK_TYPE:
-			gui_gbs_dialog_goto_bookmark(mod_name, key);
+			//gui_gbs_dialog_goto_bookmark(mod_name, key);
 			break;
 		}
 	} else
-		gui_change_module_and_key(mod_name, key);
+		main_url_handler(url);
 }
 
 
@@ -431,8 +367,8 @@ static void bibletime_bookmarks_activate(GtkMenuItem * menuitem,
 	gtk_tree_store_append(GTK_TREE_STORE(model), &iter,
 			      &parent);
 	gtk_tree_store_set(GTK_TREE_STORE(model), &iter, 
-			   COL_OPEN_PIXBUF, pixbufs->pixbuf_opened,
-			   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
+			   COL_OPEN_PIXBUF, bm_pixbufs->pixbuf_opened,
+			   COL_CLOSED_PIXBUF, bm_pixbufs->pixbuf_closed,
 			   COL_CAPTION, "BibleTime", 
 			   COL_KEY, NULL,
 			   COL_MODULE, NULL,
@@ -486,18 +422,26 @@ static void on_allow_reordering_activate(GtkMenuItem * menuitem,
 static void on_dialog_activate(GtkMenuItem * menuitem, gpointer user_data)
 {	
 	GtkTreeIter selected;
-	gchar *caption = NULL;
 	gchar *key = NULL;
-	gchar *module = NULL;
+	gchar *module = NULL;	
+	gchar *url = NULL;
+	
+	GtkTreeSelection* selection= gtk_tree_view_get_selection(bookmark_tree);
 	
 	use_dialog = TRUE; 
-	
-	if (gtk_tree_selection_get_selected(current_selection, NULL, &selected)) {
-		gtk_tree_model_get(GTK_TREE_MODEL(model), &selected,
-				   2, &caption, 3, &key, 4, &module, -1);
-		goto_bookmark(module, key);
+	if (gtk_tree_selection_get_selected(selection, NULL, &selected)) {
+		gtk_tree_model_get(GTK_TREE_MODEL(model), 
+					&selected,
+					3, &key, 
+					4, &module, 
+					-1);
+		url = g_strdup_printf("bookmark://%s/%s",module,key);
+		main_url_handler(url, TRUE);
+		g_free(url);
 	}
 	use_dialog = FALSE;
+	g_free(module);
+	g_free(key);
 }
 
 
@@ -528,56 +472,79 @@ static void on_edit_item_activate(GtkMenuItem * menuitem, gpointer user_data)
 	gchar *caption = NULL;
 	gchar *key = NULL;
 	gchar *module = NULL;
+	gchar *mod_desc = NULL;
+	gchar *description = NULL;
 	gboolean is_leaf;
+	GString *str;
+	
+	str = g_string_new(NULL);
+	g_string_printf(str,"<span weight=\"bold\">%s</span>",_("Edit"));
 	
 	selection = gtk_tree_view_get_selection(bookmark_tree);
 	if(!gtk_tree_selection_get_selected(selection, NULL, &selected)) 
 		return;	
 	gtk_tree_model_get(GTK_TREE_MODEL(model), &selected,
-				   2, &caption, 3, &key, 4, &module, -1);
+					2, &caption, 
+					3, &key, 
+					4, &module, 
+					5, &mod_desc, 
+					6, &description,
+					-1);
 	
 	info = gui_new_dialog();
 	info->title = N_("Bookmark");
-	info->label_top = N_("<b>Edit</b>");
+	info->label_top = str->str;
 	if(gtk_tree_model_iter_has_child(GTK_TREE_MODEL(model), &selected)) {
-		info->label1 = "Folder name: ";
+		info->label1 = N_("Folder name: ");
 		is_leaf = FALSE;		
-	}
-	else {
-		info->label1 = "Bookmark name: ";
+	} else {
+		info->label1 = N_("Bookmark name: ");
 		info->text2 = g_strdup(key);
 		info->text3 = g_strdup(module);
-		info->label2 = "Verse: ";
-		info->label3 = "Module: ";
+		info->label2 = N_("Verse: ");
+		info->label3 = N_("Module: ");
 		is_leaf = TRUE;		
 	}
 		
 	info->text1 = g_strdup(caption);
 	info->ok = TRUE;
 	info->cancel = TRUE;
-
+		
+	
 	test = gui_gs_dialog(info);
 	if (test == GS_OK) {
 		data = g_new(BOOKMARK_DATA,1);
+		data->caption = info->text1;
+		data->key = NULL; 		
+		data->module = NULL; 
+		data->module_desc = NULL;
+		data->description = NULL;
 		if(is_leaf) {
-			data->opened = pixbufs->pixbuf_helpdoc;
-			data->closed = NULL;
-		}
-		else {				
-			data->opened = pixbufs->pixbuf_opened;
-			data->closed = pixbufs->pixbuf_closed;	
+			data->opened = bm_pixbufs->pixbuf_helpdoc;
+			data->closed = NULL;	
+			data->key = info->text2; 		
+			data->module = info->text3; 
+			data->module_desc = main_get_module_description(info->text3);
+			if((strlen(description) > 1) || (strcmp(caption,info->text1))) {
+				data->description = info->text1;
+			}
+			else 
+				data->description = NULL;
+			data->is_leaf = TRUE;
+		} else {				
+			data->opened = bm_pixbufs->pixbuf_opened;
+			data->closed = bm_pixbufs->pixbuf_closed;
+			data->is_leaf = FALSE;
 		}
 			
-		data->caption = info->text1;
-		data->key = info->text2; 
-		data->module = info->text3; 
-		data->is_leaf = TRUE;
 		gtk_tree_store_set(GTK_TREE_STORE(model), &selected, 
 			   COL_OPEN_PIXBUF, data->opened,
 			   COL_CLOSED_PIXBUF, data->closed,
 			   COL_CAPTION, data->caption, 
 			   COL_KEY, data->key,
 			   COL_MODULE, data->module,
+			   COL_MODULE_DESC, data->module_desc,
+			   COL_DESCRIPTION, data->description,
 			   -1);	
 		bookmarks_changed = TRUE;
 		save_bookmarks(NULL, NULL);
@@ -590,6 +557,9 @@ static void on_edit_item_activate(GtkMenuItem * menuitem, gpointer user_data)
 	g_free(caption);
 	g_free(key);
 	g_free(module);
+	g_free(mod_desc);
+	g_free(description);
+	g_string_free(str,TRUE);
 }
 
 
@@ -952,16 +922,15 @@ static void on_add_bookmark_activate(GtkMenuItem * menuitem,
 	BOOKMARK_DATA * data;
 	GS_DIALOG *info;
 	gchar buf[256];
-	GString *str;
+	GString *str = g_string_new(NULL);
 	
 	
 	if (!gtk_tree_selection_get_selected(current_selection,NULL,&selected))
 		return;
 
-	mod_name = get_module_name();
-	key = get_module_key();		
+	mod_name = main_get_active_pane_module();
+	key = main_get_active_pane_key();		
 	data = g_new(BOOKMARK_DATA,1);
-	str = g_string_new("");
 	info = gui_new_dialog();
 	info->title = N_("Bookmark");
 	g_string_printf(str, "<span weight=\"bold\">%s</span>", _("Add"));
@@ -981,8 +950,13 @@ static void on_add_bookmark_activate(GtkMenuItem * menuitem,
 		data->caption = info->text1;
 		data->key = info->text2; 
 		data->module = info->text3; 
+		data->module_desc = main_get_module_description(info->text3);
+		if(!strcmp(data->caption,buf))
+			data->description = NULL;
+		else
+			data->description = info->text1;
 		data->is_leaf = TRUE;
-		data->opened = pixbufs->pixbuf_helpdoc;
+		data->opened = bm_pixbufs->pixbuf_helpdoc;
 		data->closed = NULL;			
 		add_item_to_tree(&iter,&selected, data);			
 		bookmarks_changed = TRUE;
@@ -1073,9 +1047,11 @@ static void on_new_folder_activate(GtkMenuItem * menuitem, gpointer user_data)
 		data->caption = g_strdup(buf);
 		data->key = NULL; 
 		data->module = NULL; 
+		data->module_desc = NULL;
+		data->description = NULL;
 		data->is_leaf = FALSE;
-		data->opened = pixbufs->pixbuf_opened;
-		data->closed = pixbufs->pixbuf_closed;			
+		data->opened = bm_pixbufs->pixbuf_opened;
+		data->closed = bm_pixbufs->pixbuf_closed;			
 		add_item_to_tree(&iter,&selected, data);
 		bookmarks_changed = TRUE;
 		save_bookmarks(NULL, NULL);
@@ -1087,7 +1063,42 @@ static void on_new_folder_activate(GtkMenuItem * menuitem, gpointer user_data)
 	g_string_free(str,TRUE);
 }
 
+/******************************************************************************
+ * Name
+ *   on_open_in_tab_activate
+ *
+ * Synopsis
+ *   #include "gui/.h"
+ *
+ *   void on_open_in_tab_activate(GtkMenuItem * menuitem, gpointer user_data)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   void
+ */
 
+void on_open_in_tab_activate(GtkMenuItem * menuitem, gpointer user_data)
+{
+	GtkTreeSelection* selection;
+	GtkTreeIter selected;
+	GtkTreeIter iter;
+	gchar *key = NULL;
+	gchar *module = NULL;
+	
+	
+	selection = gtk_tree_view_get_selection(bookmark_tree);
+	if (!gtk_tree_selection_get_selected(selection,NULL,&selected))
+		return;
+	gtk_tree_model_get(GTK_TREE_MODEL(model), &selected,
+				   3, &key, 
+				   4, &module, 
+			           -1);	
+	main_open_bookmark_in_new_tab(module,key);
+	g_free(key);
+	g_free(module);
+}
 
 
 /******************************************************************************
@@ -1123,6 +1134,12 @@ static GnomeUIInfo rr_menu_uiinfo[] = {
 };
 
 static GnomeUIInfo pmBookmarkTree_uiinfo[] = {
+	{
+	 GNOME_APP_UI_ITEM, N_("Open in a new tab"),
+	 N_("Open this bookmark in a dialog"),
+	 (gpointer) on_open_in_tab_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_FILENAME, PACKAGE_PIXMAPS_DIR "/new_tab_button.png",
+	 0, (GdkModifierType) 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Open in a dialog"),
 	 N_("Open this bookmark in a dialog"),
@@ -1216,22 +1233,24 @@ void gui_create_bookmark_menu(void)
 	gnome_app_fill_menu(GTK_MENU_SHELL(menu.menu),
 			    pmBookmarkTree_uiinfo, NULL, FALSE, 0);
 
-	menu.in_dialog = pmBookmarkTree_uiinfo[0].widget;
-	menu.new = pmBookmarkTree_uiinfo[1].widget;
-	menu.insert = pmBookmarkTree_uiinfo[2].widget;
-	menu.edit = pmBookmarkTree_uiinfo[3].widget;
-	menu.delete = pmBookmarkTree_uiinfo[4].widget;
+	menu.in_tab = pmBookmarkTree_uiinfo[0].widget;
+	menu.in_dialog = pmBookmarkTree_uiinfo[1].widget;
+	menu.new = pmBookmarkTree_uiinfo[2].widget;
+	menu.insert = pmBookmarkTree_uiinfo[3].widget;
+	menu.edit = pmBookmarkTree_uiinfo[4].widget;
+	menu.delete = pmBookmarkTree_uiinfo[5].widget;
 	
 	
 	
-	menu.reorder = pmBookmarkTree_uiinfo[9].widget;
+	menu.reorder = pmBookmarkTree_uiinfo[10].widget;
 
-	menu.bibletime = pmBookmarkTree_uiinfo[11].widget;
-	menu.rr_submenu = pmBookmarkTree_uiinfo[12].widget;
+	menu.bibletime = pmBookmarkTree_uiinfo[12].widget;
+	menu.rr_submenu = pmBookmarkTree_uiinfo[13].widget;
 
 	menu.remove = rr_menu_uiinfo[0].widget;
 	menu.restore = rr_menu_uiinfo[2].widget;
 
+	gtk_widget_set_sensitive(menu.in_tab, FALSE);
 	gtk_widget_set_sensitive(menu.in_dialog, FALSE);
 	gtk_widget_set_sensitive(menu.new, FALSE);
 	gtk_widget_set_sensitive(menu.insert, FALSE);
