@@ -45,14 +45,16 @@
 #include "gui/dictlex_dialog.h"
 #include "gui/gbs_dialog.h"
 #include "gui/sidebar.h"
+#include "gui/toolbar_nav.h"
 #include "gui/widgets.h"
 
 #include "main/settings.h"
+#include "main/sidebar.h"
 #include "main/sword.h"
-#include "main/key.h"
 #include "main/xml.h"
+#include "main/module_dialogs.h"
 
-TreePixbufs *pixbufs;
+//TreePixbufs *pixbufs;
 GtkTreeStore *model;
 gboolean button_one;
 gboolean button_two;
@@ -62,7 +64,7 @@ GtkTreeView *bookmark_tree;
 static gboolean save_reorderable;
 static void add_item_to_tree(GtkTreeIter *iter,GtkTreeIter *parent, BOOKMARK_DATA * data);
 
-
+BookMarksPixbufs *bm_pixbufs;
 /******************************************************************************
  * Name
  *   gui_verselist_to_bookmarks
@@ -108,13 +110,13 @@ void gui_verselist_to_bookmarks(GList * verses)
 		gtk_tree_store_append(GTK_TREE_STORE(model), &parent,
 			      &iter);	
 		gtk_tree_store_set(GTK_TREE_STORE(model), &parent, 
-			   COL_OPEN_PIXBUF, pixbufs->pixbuf_opened,
-			   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
+			   COL_OPEN_PIXBUF, bm_pixbufs->pixbuf_opened,
+			   COL_CLOSED_PIXBUF, bm_pixbufs->pixbuf_closed,
 			   COL_CAPTION, info->text1, 
 			   COL_KEY, NULL,
 			   COL_MODULE, NULL,
 			   -1);
-		set_results_position((char) 1);	// TOP 
+//		set_results_position((char) 1);	// TOP 
 		str = g_string_new(" ");
 		while (verses) {
 			list_item = (RESULTS*) verses->data;
@@ -125,7 +127,7 @@ void gui_verselist_to_bookmarks(GList * verses)
 			gtk_tree_store_append(GTK_TREE_STORE(model), &iter,
 				      &parent);		
 			gtk_tree_store_set(GTK_TREE_STORE(model), &iter, 
-				   COL_OPEN_PIXBUF, pixbufs->pixbuf_helpdoc,
+				   COL_OPEN_PIXBUF, bm_pixbufs->pixbuf_helpdoc,
 				   COL_CLOSED_PIXBUF, NULL,
 				   COL_CAPTION, str->str, 
 				   COL_KEY, tmpbuf,
@@ -187,33 +189,31 @@ void gui_save_old_bookmarks_to_new(GNode * gnode)
 static void goto_bookmark(gchar * mod_name, gchar * key)
 {
 	gint module_type;
+	gchar *val_key;
+	gchar *url = g_strdup_printf("sword://%s/%s",mod_name,key);;
 	
-	if(!check_for_module(mod_name)) 
+	if(!main_is_module(mod_name)) 
 		mod_name = settings.MainWindowModule;
 	
+	module_type = main_get_mod_type(mod_name);
 	if (use_dialog) {
-		module_type = get_mod_type(mod_name);
+		//module_type = main_get_mod_type(mod_name);
 		switch (module_type) {
 			case -1:
 				break;
 			case TEXT_TYPE:
-				gui_bibletext_dialog_goto_bookmark(mod_name,
-								   key);
-				break;
 			case COMMENTARY_TYPE:
-				gui_commentary_dialog_goto_bookmark(mod_name,
-								    key);
-				break;
 			case DICTIONARY_TYPE:
-				gui_dictionary_dialog_goto_bookmark(mod_name,
-								    key);
+				main_dialog_goto_bookmark(url);
 				break;
 			case BOOK_TYPE:
-				gui_gbs_dialog_goto_bookmark(mod_name, key);
+				//gui_gbs_dialog_goto_bookmark(mod_name, key);
 				break;
 		}
-	} else
-		gui_change_module_and_key(mod_name, key);
+	} else  {
+		main_url_handler(url, TRUE);
+	}
+	g_free(url);
 }
 
 /******************************************************************************
@@ -241,9 +241,11 @@ static void get_xml_folder_data(xmlNodePtr cur, BOOKMARK_DATA * data)
 	data->caption = g_strdup(folder);
 	data->key = NULL; //g_strdup("GROUP");
 	data->module = NULL; //g_strdup("GROUP");
+	data->module_desc = NULL; //g_strdup("GROUP");
+	data->description = NULL; //g_strdup("GROUP");
 	data->is_leaf = FALSE;
-	data->opened = pixbufs->pixbuf_opened;
-	data->closed = pixbufs->pixbuf_closed;
+	data->opened = bm_pixbufs->pixbuf_opened;
+	data->closed = bm_pixbufs->pixbuf_closed;
 }
 
 
@@ -268,21 +270,26 @@ static void get_xml_bookmark_data(xmlNodePtr cur, BOOKMARK_DATA * data)
 	xmlChar *mod1;
 	xmlChar *key;
 	xmlChar *caption;
+	xmlChar *mod_desc;
+	xmlChar *description;
 	gchar buf[500];
+	gchar *url = NULL;
 
-	data->opened = pixbufs->pixbuf_helpdoc;
+	data->opened = bm_pixbufs->pixbuf_helpdoc;
 	data->closed = NULL;
 	mod1 = xmlGetProp(cur, "modulename");
 	key = xmlGetProp(cur, "key");
-	caption = xmlGetProp(cur, "caption");	// needed to load early devel release 
-	if (caption) {
+	//caption = xmlGetProp(cur, "caption");	
+	mod_desc = xmlGetProp(cur, "moduledescription");
+	description = xmlGetProp(cur, "description"); 
+/*	if (caption) {
 		if (strlen(caption) > 0) {
 			data->caption = g_strdup(caption);
 		} else {
 			sprintf(buf, "%s, %s", key, mod1);
 			data->caption = g_strdup(buf);
 		}
-	} else {
+	} else {*/
 		caption = xmlGetProp(cur, "description");
 		if (caption) {
 			if (strlen(caption) > 0) {
@@ -293,10 +300,18 @@ static void get_xml_bookmark_data(xmlNodePtr cur, BOOKMARK_DATA * data)
 			}
 		} else
 			data->caption = g_strdup(key);
-	}
+//	}
+/*	if(strstr(key,"sword://"))
+		url = g_strdup(key);
+	else 
+		url = g_strdup_printf("sword://%s/%s",mod1,key);
+*/
 	data->key = g_strdup(key);
 	data->module = g_strdup(mod1);
+	data->description = g_strdup(description);
+	data->module_desc = g_strdup(mod_desc);
 	data->is_leaf = TRUE;
+//	if(url)	g_free(url);
 }
 
 
@@ -324,6 +339,10 @@ static void free_bookmark_data(BOOKMARK_DATA * data)
 		g_free(data->key);
 	if(data->module) 
 		g_free(data->module);
+	if(data->module_desc) 
+		g_free(data->module_desc);
+	if(data->description) 
+		g_free(data->description);
 }
 
 /******************************************************************************
@@ -354,6 +373,8 @@ static void add_item_to_tree(GtkTreeIter *iter,GtkTreeIter *parent, BOOKMARK_DAT
 			   COL_CAPTION, data->caption, 
 			   COL_KEY, data->key,
 			   COL_MODULE, data->module,
+			   COL_MODULE_DESC, data->module_desc,
+			   COL_DESCRIPTION, data->description,
 			   -1);
 }
 
@@ -608,32 +629,30 @@ static void row_deleted(GtkTreeModel * treemodel, GtkTreePath * arg1,
 
 static void create_pixbufs(void)
 {
-	GtkWidget *image;
+	//GtkWidget *image;
 	
-	pixbufs = g_new0(TreePixbufs, 1);
-	pixbufs->pixbuf_closed = gtk_widget_render_icon(widgets.app,
-                                             "epiphany-bookmarks",
-                                             GTK_ICON_SIZE_MENU,
+	bm_pixbufs = g_new0(BookMarksPixbufs, 1);
+	bm_pixbufs->pixbuf_closed = gdk_pixbuf_new_from_file(PACKAGE_PIXMAPS_DIR
+                                             "/epiphany-bookmarks.png",
                                              NULL);
-	if(!pixbufs->pixbuf_closed)
-		pixbufs->pixbuf_closed 
+	if(!bm_pixbufs->pixbuf_closed)
+		bm_pixbufs->pixbuf_closed 
 			= gtk_widget_render_icon(widgets.app,
                                              GNOME_STOCK_BOOK_BLUE, 
                                              GTK_ICON_SIZE_MENU,
                                              NULL);
 		
-	pixbufs->pixbuf_opened =
+	bm_pixbufs->pixbuf_opened =
 		gtk_widget_render_icon(widgets.app,
                                              GNOME_STOCK_BOOK_OPEN, 
                                              GTK_ICON_SIZE_MENU,
                                              NULL);
-	pixbufs->pixbuf_helpdoc =
-		gtk_widget_render_icon(widgets.app,
-                                             "epiphany-bookmark-page",
-                                             GTK_ICON_SIZE_MENU,
+	bm_pixbufs->pixbuf_helpdoc =
+		gdk_pixbuf_new_from_file(PACKAGE_PIXMAPS_DIR
+                                             "/epiphany-bookmark-page.png",
                                              NULL);
-	if(!pixbufs->pixbuf_helpdoc)
-		pixbufs->pixbuf_helpdoc 
+	if(!bm_pixbufs->pixbuf_helpdoc)
+		bm_pixbufs->pixbuf_helpdoc 
 			= gtk_widget_render_icon(widgets.app,
                                              GTK_STOCK_DND,
                                              GTK_ICON_SIZE_MENU,
@@ -696,6 +715,22 @@ static void add_columns(GtkTreeView * tree)
 					    "text", COL_MODULE, NULL);
 	gtk_tree_view_append_column(tree, column);
 	gtk_tree_view_column_set_visible(column, FALSE);
+	
+	column = gtk_tree_view_column_new();
+	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_attributes(column, renderer,
+					    "text", COL_MODULE_DESC, NULL);
+	gtk_tree_view_append_column(tree, column);
+	gtk_tree_view_column_set_visible(column, FALSE);
+	
+	column = gtk_tree_view_column_new();
+	renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_attributes(column, renderer,
+					    "text", COL_DESCRIPTION, NULL);
+	gtk_tree_view_append_column(tree, column);
+	gtk_tree_view_column_set_visible(column, FALSE);
 }
 
 
@@ -723,19 +758,22 @@ static GtkTreeModel *create_model(void)
 				   GDK_TYPE_PIXBUF,
 				   GDK_TYPE_PIXBUF,
 				   G_TYPE_STRING,
+				   G_TYPE_STRING,
+				   G_TYPE_STRING,
 				   G_TYPE_STRING, 
 				   G_TYPE_STRING);
 	return GTK_TREE_MODEL(model);	
 }
 
+
 /******************************************************************************
  * Name
- *   button_press_event
+ *   button_release_event
  *
  * Synopsis
  *   #include "gui/bookmarks_treeview.h"
  *
- *   gboolean button_press_event(GtkWidget * widget,
+ *   gboolean button_release_event(GtkWidget * widget,
 			    GdkEventButton * event, gpointer user_data)
  *
  * Description
@@ -746,7 +784,7 @@ static GtkTreeModel *create_model(void)
  *   void
  */
 
-static gboolean button_press_event(GtkWidget * widget,
+static gboolean button_release_event(GtkWidget * widget,
 			    GdkEventButton * event, gpointer data)
 {
 	GtkTreeSelection* selection = NULL;
@@ -755,6 +793,8 @@ static gboolean button_press_event(GtkWidget * widget,
 	gchar *caption = NULL;
 	gchar *key = NULL;
 	gchar *module = NULL;
+	gchar *mod_desc = NULL;
+	gchar *description = NULL;
 	button_one = FALSE;
 	button_two = FALSE;
 	
@@ -763,15 +803,22 @@ static gboolean button_press_event(GtkWidget * widget,
 	current_selection = selection;
 	if (gtk_tree_selection_get_selected(selection, NULL, &selected)) {
 		gtk_tree_model_get(GTK_TREE_MODEL(model), &selected,
-				   2, &caption, 3, &key, 4, &module, -1);
+				   2, &caption, 
+				   3, &key, 
+				   4, &module, 
+				   5, &mod_desc, 
+				   6, &description, 
+				   -1);
 		if(!gtk_tree_model_iter_has_child(GTK_TREE_MODEL(model),
 					     &selected) && key != NULL) {			
+			gtk_widget_set_sensitive(menu.in_tab, TRUE);			
 			gtk_widget_set_sensitive(menu.in_dialog, TRUE);
 			gtk_widget_set_sensitive(menu.new, FALSE);
 			gtk_widget_set_sensitive(menu.insert, FALSE);
 			gtk_widget_set_sensitive(menu.rr_submenu, FALSE);
 		}
 		else {
+			gtk_widget_set_sensitive(menu.in_tab, FALSE);
 			gtk_widget_set_sensitive(menu.in_dialog, FALSE);
 			gtk_widget_set_sensitive(menu.new, TRUE);
 			gtk_widget_set_sensitive(menu.insert, TRUE);
@@ -800,6 +847,7 @@ static gboolean button_press_event(GtkWidget * widget,
 			       NULL, NULL, NULL, NULL,
 			       event->button, event->time);
 			if(GTK_CHECK_MENU_ITEM(menu.reorder)->active) {			
+				gtk_widget_set_sensitive(menu.in_tab, FALSE);		
 				gtk_widget_set_sensitive(menu.in_dialog, FALSE);
 				gtk_widget_set_sensitive(menu.new, FALSE);
 				gtk_widget_set_sensitive(menu.insert, FALSE);
@@ -818,18 +866,18 @@ static gboolean button_press_event(GtkWidget * widget,
 			}
 			break;
 		
-	}	
-	
+	}
 	if (is_selected) {
 		if(!gtk_tree_model_iter_has_child(GTK_TREE_MODEL(model),
 				     &selected) && key != NULL) {
+			gchar *url = g_strdup_printf("bookmark://%s/%s",module,key);
 			if(button_one)
-				goto_bookmark(module, key);
-			else if(button_two) {
-				use_dialog = TRUE; 
-				goto_bookmark(module, key);
-				use_dialog = FALSE; 
-			}
+				main_url_handler(url, FALSE);
+			else if(button_two) 	
+				main_open_bookmark_in_new_tab(module,key);
+				//main_url_handler(url, TRUE);
+			g_free(url);
+			
 		}
 		g_free(caption);
 		g_free(key);
@@ -871,17 +919,21 @@ GtkWidget *gui_create_bookmark_tree(void)
 	gtk_tree_store_append(GTK_TREE_STORE(model), &iter,
 			      NULL);
 	gtk_tree_store_set(GTK_TREE_STORE(model), &iter, 
-			   COL_OPEN_PIXBUF, pixbufs->pixbuf_opened,
-			   COL_CLOSED_PIXBUF, pixbufs->pixbuf_closed,
+			   COL_OPEN_PIXBUF, bm_pixbufs->pixbuf_opened,
+			   COL_CLOSED_PIXBUF, bm_pixbufs->pixbuf_closed,
 			   COL_CAPTION,"Bookmarks", 
 			   COL_KEY, NULL,
 			   COL_MODULE,NULL,
 			   -1);
 
 	load_xml_bookmarks(GTK_TREE_VIEW(tree),&iter);
-	g_signal_connect(G_OBJECT(tree),
+	/*g_signal_connect(G_OBJECT(tree),
+				 "row-collapsed", 
+				G_CALLBACK(expand_release_cursor_row),
+				 NULL);*/
+	g_signal_connect_after(G_OBJECT(tree),
 				 "button_release_event",
-				G_CALLBACK(button_press_event),
+				G_CALLBACK(button_release_event),
 				 NULL);
 	use_dialog = FALSE;
 	bookmark_tree = GTK_TREE_VIEW(tree); 
