@@ -45,12 +45,14 @@
 #include "gui/cipher_key_dialog.h"
 #include "gui/dialog.h"
 #include "gui/bibletext.h"
-#include "gui/commentary_menu.h"
 #include "gui/hints.h"
 #include "gui/widgets.h"
+#include "gui/tabbed_browser.h"
 
+#include "main/parallel_view.h"
 #include "main/sword.h"
 #include "main/settings.h"
+#include "main/url.h"
 #include "main/xml.h"
 
 static GtkHTMLStream *htmlstream;
@@ -125,7 +127,7 @@ static void show_in_appbar(GtkWidget * appbar, gchar * key, gchar * mod)
 {
 	gchar *str;
 	gchar *text;
-	text = get_striptext(4, mod, key);
+	text = main_get_striptext(mod, key);
 	str = remove_linefeeds(text);
 	if (str) {
 		gnome_appbar_set_status(GNOME_APPBAR(appbar), str);
@@ -156,6 +158,7 @@ static void deal_with_notes(const gchar * url, gboolean clicked)
 	gchar *buf = NULL;
 	gchar *buf1 = NULL;
 	gchar *tmpbuf = NULL;
+	gchar **work_buf;
 	
 	if(!in_url) {
 		return;
@@ -167,23 +170,28 @@ static void deal_with_notes(const gchar * url, gboolean clicked)
 	buf1 = strchr(url, '=');
 	++buf1;
 	
-	if(clicked) {
-		tmpbuf = get_crossref(buf1);
-		if (!*tmpbuf)
-			return;
-		else 
-			gui_display_verse_list_in_sidebar(settings.
+	work_buf = g_strsplit (buf1,".",3);
+	
+	if(clicked && !strcmp(work_buf[1], "x")) {
+		tmpbuf = main_get_crossref(settings.MainWindowModule,
+					work_buf[0],
+					work_buf[2]);
+		if (tmpbuf)
+			main_display_verse_list_in_sidebar(settings.
 					  currentverse,
 					  xml_get_value("modules", 
 					  "bible"),
 					  tmpbuf);
-	} else {
-		tmpbuf = get_footnote_body(buf1);
+	} else if(!clicked){
+		tmpbuf = main_get_footnote_body(settings.MainWindowModule,
+					work_buf[0],
+					work_buf[2]);
 		if (tmpbuf == NULL)
 			return;
 		gui_display_in_hint_window(tmpbuf);
 	}
-	g_free(tmpbuf);
+	g_free(tmpbuf);	
+	g_strfreev(work_buf);
 }
 
 
@@ -236,7 +244,7 @@ static void deal_with_refs(const gchar * url)
 			++i;
 		}
 	}
-	if (check_for_module(newmod)) {
+	if (main_is_module(newmod)) {
 		modbuf = newmod;
 	} else {
 		modbuf = xml_get_value("modules", "bible");
@@ -244,12 +252,12 @@ static void deal_with_refs(const gchar * url)
 	buf = g_strdup(newref);
 	mod_name = g_strdup(modbuf);
 
-	if (get_mod_type(modbuf) == DICTIONARY_TYPE) {
+	if (main_get_mod_type(modbuf) == DICTIONARY_TYPE) {
 		/* we have a dict/lex module 
 		   so we don't need to get a verse list */
-		gui_display_dictlex_in_sidebar(mod_name, buf);
+		main_sidebar_display_dictlex(mod_name, buf);
 	} else {
-		gui_display_verse_list_in_sidebar(settings.currentverse,
+		main_display_verse_list_in_sidebar(settings.currentverse,
 						  mod_name,
 						  buf);
 	}
@@ -314,12 +322,12 @@ static void deal_with_storngs(const gchar * url, gboolean clicked)
 	buf = g_strdup(newref);
 	if (clicked) {
 		if (settings.inDictpane)
-			gui_change_module_and_key(modbuf, buf);
+			main_display_dictionary(modbuf, buf);
 		if (settings.inViewer)
-			gui_display_dictlex_in_sidebar(modbuf_viewer, buf);		
+			main_sidebar_display_dictlex(modbuf_viewer, buf);		
 	} else {
 		mybuf =
-		    get_module_text(get_mod_type(modbuf), modbuf, buf);
+		    main_get_rendered_text(modbuf, buf);
 		if (mybuf) {
 			//gui_display_hint_in_viewer(mybuf);
 			show_in_appbar(widgets.appbar, buf, modbuf);
@@ -367,12 +375,12 @@ static void deal_with_morphs(const gchar * url, gboolean clicked)
 		if (modbuf[0] == 'x' && modbuf[1] == '-')
 			modbuf += 2;
 		if (!strncmp(modbuf, "Robinson", 7)) {
-			if(check_for_module("Robinson"))
+			if(main_is_module("Robinson"))
 				modbuf = "Robinson";
 			else
 				return;
 		} else if (!strncmp(modbuf, "none", 4)) {
-			if(check_for_module("Packard"))
+			if(main_is_module("Packard"))
 				modbuf = "Packard";
 			else			
 				return;
@@ -404,12 +412,12 @@ static void deal_with_morphs(const gchar * url, gboolean clicked)
 	mybuf = NULL;
 	if (clicked) {		
 		if (settings.inDictpane)
-			gui_change_module_and_key(modbuf, buf);
+			main_display_dictionary(modbuf, buf);
 		if (settings.inViewer)
-			gui_display_dictlex_in_sidebar(modbuf, buf);
+			main_sidebar_display_dictlex(modbuf, buf);
 	} else {
 		mybuf =
-		    get_module_text(get_mod_type(modbuf), modbuf, buf);
+		    main_get_rendered_text(modbuf, buf);
 		if (mybuf) {
 			//gui_display_in_hint_window(mybuf);
 			show_in_appbar(widgets.appbar, buf, modbuf);
@@ -442,11 +450,18 @@ static void deal_with_morphs(const gchar * url, gboolean clicked)
 
 void gui_url(GtkHTML * html, const gchar * url, gpointer data)
 {
-	gchar buf[255];
-
+	gchar buf[500];
+	/*static guint delay = 500000;	
+			
+	while(delay != 0) {
+			--delay;
+		if (url == NULL)
+			return;
+	} 
+	delay = 500000; 
+*/
 	if (url == NULL) { /* moved out of url - clear appbar */
-		gnome_appbar_set_status(GNOME_APPBAR(widgets.appbar),
-					"");
+		gnome_appbar_set_status(GNOME_APPBAR(widgets.appbar), "");
 		in_url = FALSE;
 		if (hint.in_popup) {
 			gtk_widget_destroy(hint.hint_window);
@@ -454,26 +469,19 @@ void gui_url(GtkHTML * html, const gchar * url, gpointer data)
 		}
 	} else {
 		in_url = TRUE;	/* we need this for html_button_released */
-		if (*url == '@') { /* swap parallel and main text mods */
-			++url;
-			sprintf(buf, _("Show %s in main window"), url);
+		//g_print("url = %s\n",url);
+		if(main_url_handler(url, FALSE))
+			return;
+		
+		if (*url == 'I') {
+			return;
 		} else if (!strncmp(url, "noteID=", 7)) { /* footnote */
 			deal_with_notes(url, FALSE);
 			return;
-		} else if (*url == '[') {  /* module name */
-			++url;
-			while (*url != ']') {
-				++url;
-			}
-			++url;
-			sprintf(buf, "%s", url);
-		} else if (*url == '*') {/* verse number link */
-			++url;
-			sprintf(buf, "%s", url);
 		} else if (!strncmp(url, "type=morph", 10)) {/* morph tag */
 			deal_with_morphs(url, FALSE);
 			return;
-		} else if (!strncmp(url, "type=Strongs", 12)) {/* strongs */
+		} else if (!strncmp(url, "type=Strongs", 10)) {/* strongs */
 			deal_with_storngs(url, FALSE);			
 			return;
 		} else if (*url == 'U') {
@@ -481,7 +489,7 @@ void gui_url(GtkHTML * html, const gchar * url, gpointer data)
 			sprintf(buf, "%s %s", _("Unlock "), url);
 		} else /* any other link */
 			sprintf(buf, "%s", "");
-
+			
 		gnome_appbar_set_status(GNOME_APPBAR(widgets.appbar),
 					buf);
 	}
@@ -510,36 +518,17 @@ void gui_link_clicked(GtkHTML * html, const gchar * url, gpointer data)
 	gchar tmpbuf[255];
 	gint i = 0;
 	
+	if(main_url_handler(url, TRUE))
+		return;
+	
 	if (*url == '@') {
 		++url;
-		gui_swap_parallel_with_main((gchar *) url);
+		main_swap_parallel_with_main((gchar *) url);
 	} else if (!strncmp(url, "noteID=", 7)) {
 		deal_with_notes(url, TRUE);
 		return;
-	} else if (*url == '*') {  /* verse numbers in Bible Text window */
-		++url;
-		buf = g_strdup(url);
-		gui_change_verse(buf);
-		g_free(buf);
-		return;
-	} else if (*url == 'I') {
-		++url;
-		buf = g_strdup(url);
-		gui_change_verse(buf);
-		g_free(buf);
-		return;
-	} else if (*url == '[') {/* module name  */
-		++url;
-		i = 0;
-		while (*url != ']') {
-			tmpbuf[i++] = *url;
-			tmpbuf[i + 1] = '\0';
-			++url;
-		}
-		gui_display_about_module_dialog(tmpbuf, FALSE);
-		return;
 	} else if (!strncmp(url, "version=", 7)||!strncmp(url, "passage=", 7)) {
-		deal_with_refs(url);/* thml verse reference */
+		deal_with_refs(url);/* thml verse reference *//* for old notes */
 		return;
 	} else if (!strncmp(url, "type=morph", 10)) {/* thml and osis morph tag */
 		deal_with_morphs(url, TRUE);
@@ -547,16 +536,7 @@ void gui_link_clicked(GtkHTML * html, const gchar * url, gpointer data)
 	} else if (!strncmp(url, "type=Strongs", 12)) {/* gbf thml and osis strongs */		
 		deal_with_storngs(url, TRUE);
 		return;
-	} else if (*url == 'U') {
-		++url;		/* remove U */
-		buf = g_strdup(url);
-		if (get_mod_type(buf) == TEXT_TYPE) {
-			gui_unlock_bibletext(NULL, (TEXT_DATA *) data);
-		} else if (get_mod_type(buf) == COMMENTARY_TYPE) {
-			gui_unlock_commentary(NULL, (COMM_DATA *) data);
-		}
-		g_free(buf);
-	}
+	} 
 }
 
 
@@ -865,7 +845,7 @@ static struct footer_info *footer_info_new(GtkHTML * html,
 	struct footer_info *info;
 
 	info = g_new(struct footer_info, 1);
-	info->local_font = gnome_font_find_closest("Helvetica", 10.0);
+	info->local_font = gnome_font_find_closest("Luxi Sans", 10.0);
 
 	if (info->local_font)
 		*line =
