@@ -2,7 +2,7 @@
  * GnomeSword Bible Study Tool
  * main_menu.c - creation of and call backs for gnomesword main menu
  *
- * Copyright (C) 2000,2001,2002,2003 GnomeSword Developer Team
+ * Copyright (C) 2000,2001,2002,2003,2004 GnomeSword Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,32 +26,26 @@
 #include <gnome.h>
 #include <gal/shortcut-bar/e-shortcut-bar.h>
 
+#include "gui/about_gnomesword.h"
+#include "gui/about_sword.h"
+#include "gui/gnomesword.h"
+#include "gui/hints.h"
+#include "gui/history.h"
+#include "gui/html.h"
 #include "gui/main_window.h"
 #include "gui/main_menu.h"
 #include "gui/preferences_dialog.h"
 #include "gui/sidebar.h"
-#include "gui/bibletext_dialog.h"
-#include "gui/commentary_dialog.h"
-#include "gui/dictlex_dialog.h"
-#include "gui/gbs_dialog.h"
-#include "gui/history.h"
-#include "gui/html.h"
-#include "gui/utilities.h"
-#include "gui/about_modules.h"
-#include "gui/gnomesword.h"
+#include "gui/sidebar_dialog.h"
 #include "gui/search_dialog.h"
 #include "gui/studypad_dialog.h"
-#include "gui/about_gnomesword.h"
-#include "gui/about_sword.h"
-#include "gui/hints.h"
+#include "gui/utilities.h"
 #include "gui/widgets.h"
-#include "gui/sidebar_dialog.h"
 
-#include "main/sword.h"
 #include "main/bibletext.h"
 #include "main/lists.h"
-
-GtkWidget *htmlTexts;
+#include "main/sword.h"
+#include "main/search_dialog.h"
 
 
 
@@ -99,7 +93,8 @@ void on_help_contents_activate(GtkMenuItem * menuitem,
 {	
 	GError *error = NULL;
 	
-	if (gnome_help_display ((const gchar*)"gnomesword2.xml", NULL, &error) == FALSE) {
+	if (gnome_help_display ((const gchar*)"gnomesword.xml", 
+			NULL, &error) == FALSE) {
 		g_warning(error->message);
 		g_error_free (error);        
 	}
@@ -239,15 +234,26 @@ void on_search_activate(GtkMenuItem * menuitem, gpointer user_data)
  *   void
  */
 
-void on_verse_style1_activate(GtkMenuItem * menuitem,
+static void on_verse_style1_activate(GtkCheckMenuItem * menuitem,
 			      gpointer user_data)
 {
-	/* remember our choice for the next program startup */
-	settings.versestyle = GTK_CHECK_MENU_ITEM(menuitem)->active;
-
-	if (settings.havebible) {
-		/* show the change */
-		gui_display_text(settings.currentverse);
+	extern gboolean style_display;
+	if(style_display) {
+		gchar *file = g_strdup_printf("%s/modops.conf", 
+						settings.gSwordDir);
+		gchar *url = g_strdup_printf(	"sword://%s/%s",
+						settings.MainWindowModule,
+						settings.currentverse);
+		/* remember our choice for the next program startup */
+		settings.versestyle = menuitem->active;
+		save_conf_file_item(file, settings.MainWindowModule, "style",
+				(menuitem->active)?"verse":"paragraph");
+		if (settings.havebible) {
+			/* show the change */
+			main_url_handler(url, TRUE);		
+		}
+		g_free(url);
+		g_free(file);
 	}
 }
 
@@ -323,95 +329,6 @@ void on_about_gnomesword1_activate(GtkMenuItem * menuitem,
 	gtk_widget_show(AboutBox);
 }
 
-/******************************************************************************
- * Name
- *  
- *
- * Synopsis
- *   #include "gui/main_menu.h"
- *
- *   v	
- *
- * Description
- *    
- *
- * Return value
- *   void
- */
-
-static void on_bibletext_item_activate(GtkMenuItem * menuitem,
-				       gpointer user_data)
-{
-	gui_open_bibletext_dialog((gchar *) user_data);
-}
-
-/******************************************************************************
- * Name
- *  
- *
- * Synopsis
- *   #include "gui/main_menu.h"
- *
- *   v	
- *
- * Description
- *    
- *
- * Return value
- *   void
- */
-
-static void on_commentary_item_activate(GtkMenuItem * menuitem,
-					gpointer user_data)
-{
-	gui_open_commentary_dialog((gchar *) user_data);
-}
-
-/******************************************************************************
- * Name
- *   on_dictlex_item_activate
- *
- * Synopsis
- *   #include "gui/main_menu.h"
- *
- *   void on_dictlex_item_activate(GtkMenuItem * menuitem,
-				     gpointer user_data)
- *
- * Description
- *    
- *
- * Return value
- *   void
- */
-
-static void on_dictlex_item_activate(GtkMenuItem * menuitem,
-				     gpointer user_data)
-{
-	gui_open_dictlex_dialog((gchar *) user_data);
-}
-
-/******************************************************************************
- * Name
- *   on_book_item_activate
- *
- * Synopsis
- *   #include "gui/main_menu.h"
- *
- *   void on_book_item_activate(GtkMenuItem * menuitem,
-				  gpointer user_data)	
- *
- * Description
- *    
- *
- * Return value
- *   void
- */
-
-static void on_book_item_activate(GtkMenuItem * menuitem,
-				  gpointer user_data)
-{
-	gui_open_gbs_dialog((gchar *) user_data);
-}
 
 /******************************************************************************
  * Name
@@ -510,6 +427,28 @@ static void view_lower_workbook(GtkMenuItem * menuitem,
 }
 
 
+/******************************************************************************
+ * Name
+ *   on_mod_mgr
+ *
+ * Synopsis
+ *   #include "gui/main_menu.h"
+ *
+ *   void on_mod_mgr(GtkMenuItem * menuitem, gpointer user_data)	
+ *
+ * Description
+ *    
+ *
+ * Return value
+ *   void
+ */
+
+static void on_mod_mgr(GtkMenuItem * menuitem,
+				gpointer user_data)
+{
+	gui_open_mod_mgr();
+}
+
 /******************************************************************************
  * Name
  *   open_studypad
@@ -534,17 +473,9 @@ static void open_studypad(GtkMenuItem * menuitem, gpointer user_data)
 		gdk_window_raise(GTK_WIDGET(widgets.studypad_dialog)->
 				 window);
 	} else {
-		if (settings.use_studypad_dialog) {
-			settings.studypad_dialog_exist =
-			    gui_open_studypad_dialog(settings.
-						     studypadfilename);
-		} else {
-			gtk_notebook_set_current_page(GTK_NOTEBOOK
-					      (widgets.workbook_lower),
-					      settings.studypad_page);
-		}
+		settings.studypad_dialog_exist =
+			  gui_open_studypad_dialog(settings.studypadfilename);
 	}
-
 }
 
 
@@ -552,26 +483,6 @@ static void open_studypad(GtkMenuItem * menuitem, gpointer user_data)
  * gnome menu structures
  */
 
-static GnomeUIInfo open_bibletext_dialog1_menu_uiinfo[] = {
-	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo open_commentary_dialog1_menu_uiinfo[] = {
-	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo open_dict_lex_dialog1_menu_uiinfo[] = {
-	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo open_book_dialog1_menu_uiinfo[] = {
-	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_END
-};
-
 static GnomeUIInfo file1_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("Open StudyPad"),
@@ -579,32 +490,7 @@ static GnomeUIInfo file1_menu_uiinfo[] = {
 	 open_studypad, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
-	GNOMEUIINFO_SEPARATOR,/*
-	{
-	 GNOME_APP_UI_SUBTREE, N_("Open Bibletext Dialog"),
-	 NULL,
-	 open_bibletext_dialog1_menu_uiinfo, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_BOOK_RED,
-	 0, (GdkModifierType) 0, NULL},
-	{
-	 GNOME_APP_UI_SUBTREE, N_("Open Commentary Dialog"),
-	 NULL,
-	 open_commentary_dialog1_menu_uiinfo, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_BOOK_BLUE,
-	 0, (GdkModifierType) 0, NULL},
-	{
-	 GNOME_APP_UI_SUBTREE, N_("Open Dictionary Dialog"),
-	 NULL,
-	 open_dict_lex_dialog1_menu_uiinfo, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_BOOK_GREEN,
-	 0, (GdkModifierType) 0, NULL},
-	{
-	 GNOME_APP_UI_SUBTREE, N_("Open Book Dialog"),
-	 NULL,
-	 open_book_dialog1_menu_uiinfo, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_BOOK_YELLOW,
-	 0, (GdkModifierType) 0, NULL},
-	GNOMEUIINFO_SEPARATOR,*/
+	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_EXIT_ITEM(on_exit_activate, NULL),
 	GNOMEUIINFO_END
 };
@@ -626,12 +512,18 @@ static GnomeUIInfo edit1_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("Advanced Search"),
 	 N_("Advanced search using the search dialog"),
-	 gui_do_dialog_search, NULL, NULL,
+	 main_open_search_dialog, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_BOOK_OPEN,
 	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_PREFERENCES_ITEM(on_preferences1_activate,
 					  NULL),
+	{
+	 GNOME_APP_UI_ITEM, N_("Module Manager"),
+	 N_("Use module manager to install and remove Sword modules"),
+	 on_mod_mgr, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gtk-preferences",
+	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_END
 };
 
@@ -691,13 +583,13 @@ static GnomeUIInfo view1_menu_uiinfo[] = {
 	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
-	 GNOME_APP_UI_ITEM, N_("Attach/Detach Shortcut Bar"),
+	 GNOME_APP_UI_ITEM, N_("Attach/Detach Sidebar"),
 	 NULL,
 	 gui_attach_detach_sidebar, NULL, NULL, 
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, (GdkModifierType) 0, NULL},
 	{
-	 GNOME_APP_UI_ITEM, N_("Show/Hide Shortcut Bar"),
+	 GNOME_APP_UI_ITEM, N_("Show/Hide Sidebar"),
 	 NULL,
 	 gui_sidebar_showhide, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
@@ -705,54 +597,6 @@ static GnomeUIInfo view1_menu_uiinfo[] = {
 	GNOMEUIINFO_END
 };
 
-static GnomeUIInfo bible_texts1_menu_uiinfo[] = {
-	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo commentaries1_menu_uiinfo[] = {
-	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo dictionaries_lexicons1_menu_uiinfo[] = {
-	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo books_menu_uiinfo[] = {
-	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo about_sword_modules1_menu_uiinfo[] = {
-	{
-	 GNOME_APP_UI_SUBTREE, N_("Bible Texts"),
-	 N_("Information about Bible texts"),
-	 bible_texts1_menu_uiinfo, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL,
-	 0, 0, NULL},
-	{
-	 GNOME_APP_UI_SUBTREE, N_("Commentaries"),
-	 NULL,
-	 commentaries1_menu_uiinfo, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL,
-	 0, 0, NULL},
-	{
-	 GNOME_APP_UI_SUBTREE, N_("Dictionaries-Lexicons"),
-	 NULL,
-	 dictionaries_lexicons1_menu_uiinfo, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL,
-	 0, 0, NULL},
-	{
-	 GNOME_APP_UI_SUBTREE, N_("Books"),
-	 NULL,
-	 books_menu_uiinfo, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL,
-	 0, 0, NULL},
-	GNOMEUIINFO_END
-};
-
 static GnomeUIInfo help1_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("Contents"),
@@ -796,18 +640,18 @@ static GnomeUIInfo menubar1_uiinfo[] = {
 	 edit1_menu_uiinfo, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, (GdkModifierType) 0, NULL},
-	{
-	 GNOME_APP_UI_SUBTREE, N_("H_istory"),
-	 NULL,
-	 history1_menu_uiinfo, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL,
-	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_SUBTREE, N_("_View"),
 	 NULL,
 	 view1_menu_uiinfo, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, (GdkModifierType) 0, NULL},
+	{
+	 GNOME_APP_UI_SUBTREE, N_("Hi_story"),
+	 NULL,
+	 history1_menu_uiinfo, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_SUBTREE, N_("_Help"),
 	 NULL,
