@@ -2,7 +2,7 @@
  * GnomeSword Bible Study Tool
  * main_window.c - main window gui
  *
- * Copyright (C) 2000,2001,2002 GnomeSword Developer Team
+ * Copyright (C) 2000,2001,2002,2003,2004 GnomeSword Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,11 @@
 #endif
 
 #include <gnome.h>
+#include <gtkhtml/gtkhtml.h>
+
 #include "main/sword.h"
 #include "main/settings.h"
+#include "main/xml.h"
 
 #include "gui/gnomesword.h"
 #include "gui/main_window.h"
@@ -39,7 +42,7 @@
 #include "gui/history.h"
 #include "gui/bibletext.h"
 #include "gui/parallel_view.h"
-#include "gui/percomm.h"
+//#include "gui/percomm.h"
 #include "gui/commentary.h"
 #include "gui/gbs.h"
 #include "gui/dictlex.h"
@@ -50,87 +53,6 @@
 
 WIDGETS widgets;
 
-static char *book_open_xpm[] = {
-	"16 16 4 1",
-	"       c None s None",
-	".      c black",
-	"X      c #808080",
-	"o      c white",
-	"                ",
-	"  ..            ",
-	" .Xo.    ...    ",
-	" .Xoo. ..oo.    ",
-	" .Xooo.Xooo...  ",
-	" .Xooo.oooo.X.  ",
-	" .Xooo.Xooo.X.  ",
-	" .Xooo.oooo.X.  ",
-	" .Xooo.Xooo.X.  ",
-	" .Xooo.oooo.X.  ",
-	"  .Xoo.Xoo..X.  ",
-	"   .Xo.o..ooX.  ",
-	"    .X..XXXXX.  ",
-	"    ..X.......  ",
-	"     ..         ",
-	"                "
-};
-
-static char *book_closed_xpm[] = {
-	"16 16 6 1",
-	"       c None s None",
-	".      c black",
-	"X      c red",
-	"o      c yellow",
-	"O      c #808080",
-	"#      c white",
-	"                ",
-	"       ..       ",
-	"     ..XX.      ",
-	"   ..XXXXX.     ",
-	" ..XXXXXXXX.    ",
-	".ooXXXXXXXXX.   ",
-	"..ooXXXXXXXXX.  ",
-	".X.ooXXXXXXXXX. ",
-	".XX.ooXXXXXX..  ",
-	" .XX.ooXXX..#O  ",
-	"  .XX.oo..##OO. ",
-	"   .XX..##OO..  ",
-	"    .X.#OO..    ",
-	"     ..O..      ",
-	"      ..        ",
-	"                "
-};
-
-static char *mini_page_xpm[] = {
-	"16 16 4 1",
-	"       c None s None",
-	".      c black",
-	"X      c white",
-	"o      c #808080",
-	"                ",
-	"   .......      ",
-	"   .XXXXX..     ",
-	"   .XoooX.X.    ",
-	"   .XXXXX....   ",
-	"   .XooooXoo.o  ",
-	"   .XXXXXXXX.o  ",
-	"   .XooooooX.o  ",
-	"   .XXXXXXXX.o  ",
-	"   .XooooooX.o  ",
-	"   .XXXXXXXX.o  ",
-	"   .XooooooX.o  ",
-	"   .XXXXXXXX.o  ",
-	"   ..........o  ",
-	"    oooooooooo  ",
-	"                "
-};
-
-GdkPixmap *pixmap1;
-GdkPixmap *pixmap2;
-GdkPixmap *pixmap3;
-GdkBitmap *mask1;
-GdkBitmap *mask2;
-GdkBitmap *mask3;
-
 extern HISTORY history_list[];	/* sturcture for storing history items */
 extern gint history_items;
 
@@ -142,7 +64,7 @@ extern gint history_items;
  * Synopsis
  *   #include "gui/main_window.h"
  *
- *   void gui_show_hide_texts(gboolean choice)	
+ *   void gui_show_hide_texts(gboolean choice)
  *
  * Description
  *    Show/hide bible texts
@@ -170,7 +92,7 @@ void gui_show_hide_texts(gboolean choice)
  * Synopsis
  *   #include "gui/main_window.h"
  *
- *   void gui_show_hide_comms(gboolean choice)	
+ *   void gui_show_hide_comms(gboolean choice)
  *
  * Description
  *    Show/hide Commentaries
@@ -183,9 +105,9 @@ void gui_show_hide_comms(gboolean choice)
 {
 	settings.showcomms = choice;
 	if (choice == FALSE) {
-		gtk_widget_hide(widgets.notebook_comm);
+		gtk_widget_hide(widgets.box_comm);
 	} else {
-		gtk_widget_show(widgets.notebook_comm);
+		gtk_widget_show(widgets.box_comm);
 	}
 	gui_set_bible_comm_layout();
 }
@@ -198,7 +120,7 @@ void gui_show_hide_comms(gboolean choice)
  * Synopsis
  *   #include "gui/main_window.h"
  *
- *   void gui_show_hide_dicts(gboolean choice)	
+ *   void gui_show_hide_dicts(gboolean choice)
  *
  * Description
  *    Show/hide Dictionaries-Lexicons
@@ -211,9 +133,9 @@ void gui_show_hide_dicts(gboolean choice)
 {
 	settings.showdicts = choice;
 	if (choice == FALSE) {
-		gtk_widget_hide(widgets.workbook_lower);
+		gtk_widget_hide(widgets.box_dict);
 	} else {
-		gtk_widget_show(widgets.workbook_lower);
+		gtk_widget_show(widgets.box_dict);
 	}
 	gui_set_bible_comm_layout();
 }
@@ -226,10 +148,10 @@ void gui_show_hide_dicts(gboolean choice)
  * Synopsis
  *   #include "gui/main_window.h"
  *
- *   void gui_set_bible_comm_layout(void)	
+ *   void gui_set_bible_comm_layout(void)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -281,10 +203,10 @@ void gui_set_bible_comm_layout(void)
  * Synopsis
  *   #include "gui/main_window.h"
  *
- *   void gui_change_window_title(gchar * module_name)	
+ *   void gui_change_window_title(gchar * module_name)
  *
  * Description
- *    
+ *
  *
  * Return value
  *   void
@@ -294,152 +216,14 @@ void gui_change_window_title(gchar * module_name)
 {
 	gchar title[200];
 	/*
-	 * set program title to current module name 
+	 * set program title to current module name
 	 */
-	sprintf(title, "%s - %s", get_module_description(module_name), 
+	sprintf(title, "%s - %s", main_get_module_description(module_name),
 						settings.program_title);
 	gtk_window_set_title(GTK_WINDOW(widgets.app), title);
 }
 
 
-
-
-/******************************************************************************
- * Name
- *  gui_change_module_and_key
- *
- * Synopsis
- *   #include "gui/main_window.h"
- *
- *   void gui_change_module_and_key(gchar * module_name, gchar * key)	
- *
- * Description
- *    
- *
- * Return value
- *   void
- */
-
-void gui_change_module_and_key(gchar * module_name, gchar * key)
-{
-	gint mod_type;
-	gint page_num;
-	gchar *val_key = NULL;
-
-	mod_type = get_mod_type(module_name);
-
-	switch (mod_type) {
-	case TEXT_TYPE:
-		if (settings.havebible) {
-			page_num =
-			    get_module_number(module_name, TEXT_MODS);
-			val_key = gui_update_nav_controls(key);
-			gui_set_text_page_and_key(page_num, val_key);
-			free(val_key);
-		}
-		break;
-	case COMMENTARY_TYPE:
-		if (settings.havecomm) {
-			page_num =
-			    get_module_number(module_name, COMM_MODS);
-			gui_set_commentary_page_and_key(page_num, key);
-		}
-		break;
-	case DICTIONARY_TYPE:
-		if (settings.havedict) {
-			page_num =
-			    get_module_number(module_name, DICT_MODS);
-			if(page_num == -1)
-				page_num == 0;
-			gui_set_dictionary_page_and_key(page_num, key);
-		}
-		break;
-	case BOOK_TYPE:
-		if (settings.havebook) {
-			page_num =
-			    get_module_number(module_name, BOOK_MODS);
-			if (key)
-				gui_set_book_page_and_key(page_num,
-							  key);
-			else {
-				gtk_notebook_set_current_page(GTK_NOTEBOOK
-						      (widgets.
-						       notebook_gbs),
-						      page_num);
-			}
-		}
-		break;
-	}
-}
-
-
-/******************************************************************************
- * Name
- *  gui_change_verse
- *
- * Synopsis
- *   #include "gui/main_window.h"
- *
- *   void gui_change_verse(gchar * key)	
- *
- * Description
- *    
- *
- * Return value
- *   void
- */
-
-void gui_change_verse(const gchar * key)
-{
-	gchar *val_key;
-
-	settings.apply_change = FALSE;
-	//g_warning(key);
-	val_key = gui_update_nav_controls(key);
-	if (settings.havebible) {
-		/* add item to history */
-		if (settings.addhistoryitem) {
-			if (strcmp(settings.currentverse,
-			     history_list[history_items - 1].verseref))
-				gui_add_history_Item(widgets.app,
-					       GTK_WIDGET
-					       (widgets.shortcutbar),
-					       settings.currentverse);
-		}
-		settings.addhistoryitem = TRUE;
-
-		/* change main window */
-		gui_display_text(val_key);
-		gui_keep_bibletext_dialog_in_sync(val_key);
-	}
-
-	/* 
-	 * change parallel verses 
-	 */
-	if (settings.dockedInt) {
-		gui_update_parallel_page();
-	}
-
-	/* 
-	 * change personal notes editor   if not in edit mode 
-	 */
-	if (!settings.editnote)
-		if (settings.havepercomm)
-			if (!settings.use_percomm_dialog)
-				gui_display_percomm(val_key);
-
-	/* 
-	 * set commentary module to current verse 
-	 */
-	if (settings.havecomm) {
-		gui_display_commentary(val_key);
-		gui_keep_comm_dialog_in_sync(val_key);
-	}
-
-	free(val_key);
-}
-
-
 /******************************************************************************
  * Name
  *   on_mainwindow_destroy
@@ -450,7 +234,7 @@ void gui_change_verse(const gchar * key)
  *   void on_mainwindow_destroy(GtkObject * object, gpointer user_data)
  *
  * Description
- *    shutdown gnomesword 
+ *    shutdown gnomesword
  *
  * Return value
  *   void
@@ -462,6 +246,7 @@ static void on_mainwindow_destroy(GtkObject * object,
 	shutdown_frontend();
 	/* shutdown the sword stuff */
 	shutdown_backend();
+	gtk_main_quit();
 	gtk_exit(0);
 }
 
@@ -477,7 +262,7 @@ static void on_mainwindow_destroy(GtkObject * object,
  *			GdkEventButton * event, gpointer user_data)
  *
  * Description
- *    get and store pane sizes 
+ *    get and store pane sizes
  *
  * Return value
  *   void
@@ -519,15 +304,15 @@ static gboolean epaned_button_release_event(GtkWidget * widget,
 
 /******************************************************************************
  * Name
- *   
+ *
  *
  * Synopsis
  *   #include "gui/main_window.h"
  *
- *   
+ *
  *
  * Description
- *     
+ *
  *
  * Return value
  *   void
@@ -567,7 +352,7 @@ void gui_search_appbar_update(char percent, void *userData)
  *				   gpointer user_data)
  *
  * Description
- *     
+ *
  *
  * Return value
  *   gboolean
@@ -582,12 +367,12 @@ static gboolean on_configure_event(GtkWidget * widget,
 	gint y;
 
  	gdk_window_get_root_origin(GDK_WINDOW(widgets.app->window), &x, &y);
-	
+
 	settings.gs_width = event->width;
 	settings.gs_hight = event->height;
 	settings.app_x = x;
 	settings.app_y = y;
-	
+
 	sprintf(layout, "%d", settings.gs_width);
 	xml_set_value("GnomeSword", "layout", "width", layout);
 
@@ -614,7 +399,7 @@ static gboolean on_configure_event(GtkWidget * widget,
  *   void create_mainwindow(void)
  *
  * Description
- *    create gnomesword gui 
+ *    create gnomesword gui
  *
  * Return value
  *   void
@@ -629,12 +414,12 @@ void create_mainwindow(void)
 	GtkWidget *hbox2;
 	GtkWidget *nav_toolbar;
 	GtkWidget *swInt;
-	GtkWidget *label41;
-	GtkWidget *label185;
-	GtkWidget *label197;
 	GtkWidget *hbox25;
-	GdkColor transparent = { 0 };
-	gint page_num = 0;
+	GtkWidget *hboxtb;
+	GtkWidget *tab_button_icon;
+	GtkTooltips *tooltips;
+
+	tooltips = gtk_tooltips_new ();
 
 	g_print("%s\n", "Building GnomeSword interface");
 
@@ -667,9 +452,7 @@ void create_mainwindow(void)
 
 	widgets.epaned = gtk_hpaned_new();
 	gtk_widget_show(widgets.epaned);
-	gtk_box_pack_start(GTK_BOX(hbox25), widgets.epaned,
-			   TRUE, TRUE, 0);
-
+	gtk_box_pack_start(GTK_BOX(hbox25), widgets.epaned, TRUE, TRUE, 0);
 
 	mainPanel = gtk_vbox_new(FALSE, 0);
 	gtk_paned_pack2(GTK_PANED(widgets.epaned), mainPanel,
@@ -681,25 +464,52 @@ void create_mainwindow(void)
 	gtk_box_pack_start(GTK_BOX(mainPanel), vboxMain, TRUE, TRUE, 0);
 
 	/*
-	 * nav toolbar 
+	 * notebook to have separate passages opened at once
+	 * the passages are not actually open but are switched
+	 * between similar to bookmarks
 	 */
+	widgets.hboxtb = gtk_hbox_new(FALSE, 0);
+	if(settings.browsing)
+		gtk_widget_show(widgets.hboxtb);
+	gtk_box_pack_start(GTK_BOX(vboxMain), widgets.hboxtb, FALSE, FALSE, 0);
 
-	nav_toolbar = gui_create_nav_toolbar(widgets.app);
-	/*gtk_box_pack_start(GTK_BOX(vboxMain), nav_toolbar, FALSE,
-	   FALSE, 0); */
+	widgets.button_new_tab = gtk_button_new();
+	//don't show button here in case !settings.browsing
+
+//	tab_button_icon = gtk_image_new_from_stock(GTK_STOCK_NEW,
+//					GTK_ICON_SIZE_SMALL_TOOLBAR);
+	tab_button_icon = gtk_image_new_from_file(PACKAGE_PIXMAPS_DIR
+						"/new_tab_button.png");
+	gtk_widget_show(tab_button_icon);
+	gtk_container_add(GTK_CONTAINER(widgets.button_new_tab), tab_button_icon);
+	gtk_button_set_relief(GTK_BUTTON(widgets.button_new_tab), GTK_RELIEF_NONE);
+	gtk_box_pack_start(GTK_BOX(widgets.hboxtb), widgets.button_new_tab, FALSE, FALSE, 0);
+	gtk_tooltips_set_tip(tooltips, widgets.button_new_tab, _("Open a new tab"),
+				NULL);
+
+	widgets.notebook_main = gtk_notebook_new();gtk_widget_show(widgets.notebook_main);
+	gtk_box_pack_start(GTK_BOX(widgets.hboxtb),
+			   widgets.notebook_main, TRUE, TRUE, 0);
+	gtk_widget_set_size_request(widgets.notebook_main, -1, 25);
+	gtk_notebook_set_scrollable (GTK_NOTEBOOK(widgets.notebook_main),
+                                             TRUE);
+	gtk_notebook_popup_enable(GTK_NOTEBOOK(widgets.notebook_main));
+	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.notebook_main), FALSE);
+	/* main passage tabbed notebook end */
 
 	/*
-	 * end nav toolbar 
+	 * nav toolbar
+	 */
+	nav_toolbar = gui_create_nav_toolbar(widgets.app);
+	/* gtk_box_pack_start(GTK_BOX(vboxMain),nav_toolbar,FALSE,FALSE,0); */
+	/*
+	 * end nav toolbar
 	 */
-
 
 	widgets.vpaned = gtk_vpaned_new();
 	gtk_widget_show(widgets.vpaned);
-	gtk_box_pack_end(GTK_BOX(vboxMain), widgets.vpaned,
-			 TRUE, TRUE, 0);
-	gtk_container_set_border_width(GTK_CONTAINER
-				       (widgets.vpaned), 1);
-
+	gtk_box_pack_end(GTK_BOX(vboxMain), widgets.vpaned, TRUE, TRUE, 0);
+	gtk_container_set_border_width(GTK_CONTAINER(widgets.vpaned), 1);
 
 	hbox2 = gtk_hbox_new(FALSE, 0);
 	gtk_widget_show(hbox2);
@@ -707,14 +517,13 @@ void create_mainwindow(void)
 
 	widgets.hpaned = gtk_hpaned_new();
 	gtk_widget_show(widgets.hpaned);
-	gtk_box_pack_start(GTK_BOX(hbox2), widgets.hpaned, TRUE,
-			   TRUE, 0);
-
+	gtk_box_pack_start(GTK_BOX(hbox2), widgets.hpaned, TRUE, TRUE, 0);
 
 	widgets.vbox_text = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(widgets.vbox_text);
 	gtk_paned_pack1(GTK_PANED(widgets.hpaned),
-			widgets.vbox_text, FALSE, TRUE);
+					widgets.vbox_text, FALSE, TRUE);
+
 
 	/*
 	 * text/parallel notebook
@@ -724,51 +533,36 @@ void create_mainwindow(void)
 	gtk_box_pack_start(GTK_BOX(widgets.vbox_text),
 			   widgets.notebook_parallel_text, TRUE,
 			   TRUE, 0);
-	gtk_notebook_set_show_tabs(GTK_NOTEBOOK
-				   (widgets.
+	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widgets.
 				    notebook_parallel_text), FALSE);
-	gtk_notebook_set_show_border(GTK_NOTEBOOK
-				     (widgets.
+	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.
 				      notebook_parallel_text), FALSE);
 
 	/*
 	 * text notebook
-	 */
-	widgets.notebook_text = gtk_notebook_new();
-	gtk_widget_show(widgets.notebook_text);
-	label41 = gtk_label_new(_("Biblical Text"));
-	gtk_widget_show(label41);
-
-	gtk_notebook_append_page(GTK_NOTEBOOK
-				 (widgets.
-				  notebook_parallel_text),
-				 widgets.notebook_text, label41);
+	 */	 
+	widgets.notebook_text = gui_create_bible_pane();      
+        gtk_container_add(GTK_CONTAINER(widgets.notebook_parallel_text),
+			  widgets.notebook_text);
 	gtk_notebook_set_scrollable(GTK_NOTEBOOK
 				    (widgets.notebook_text), TRUE);
-	gtk_notebook_popup_enable(GTK_NOTEBOOK(widgets.notebook_text));
-	gtk_notebook_set_show_border(GTK_NOTEBOOK
-				     (widgets.notebook_text), FALSE);
+	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(widgets.notebook_text),FALSE);
+	gtk_notebook_set_show_border(GTK_NOTEBOOK(widgets.notebook_text),FALSE);
+	gtk_notebook_popup_disable(GTK_NOTEBOOK(widgets.notebook_text));
+
 
 	/*
-	 * commentary notebook
+	 * commentary and book pane
 	 */
-	widgets.notebook_comm = gtk_notebook_new();
-	gtk_widget_show(widgets.notebook_comm);
-	gtk_notebook_set_scrollable(GTK_NOTEBOOK
-				    (widgets.notebook_comm), TRUE);
-	gtk_notebook_popup_enable(GTK_NOTEBOOK(widgets.notebook_comm));
-	gtk_notebook_set_show_border(GTK_NOTEBOOK
-				     (widgets.notebook_comm), FALSE);
-
+	widgets.box_comm = gui_create_commentary_pane();
 	gtk_paned_pack2(GTK_PANED(widgets.hpaned),
-			widgets.notebook_comm, TRUE, TRUE);
+			widgets.box_comm, TRUE, TRUE);
 
 	/*
 	 * lower_workbook
 	 */
-	widgets.workbook_lower = gtk_notebook_new();
+/*	widgets.workbook_lower = gtk_notebook_new();
 	gtk_widget_show(widgets.workbook_lower);
-	gtk_notebook_popup_enable(GTK_NOTEBOOK(widgets.workbook_lower));
 	gtk_notebook_set_show_border(GTK_NOTEBOOK
 				     (widgets.workbook_lower), FALSE);
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK
@@ -776,50 +570,24 @@ void create_mainwindow(void)
 
 	gtk_paned_pack2(GTK_PANED(widgets.vpaned),
 			widgets.workbook_lower, TRUE, TRUE);
-
+*/
 	/*
-	 * dict/lex  
-	 */
-	widgets.notebook_dict = gtk_notebook_new();
-	gtk_widget_show(widgets.notebook_dict);
-	gtk_container_add(GTK_CONTAINER(widgets.workbook_lower),
-			  widgets.notebook_dict);
-	gtk_notebook_set_scrollable(GTK_NOTEBOOK
-				    (widgets.notebook_dict), TRUE);
-	gtk_notebook_popup_enable(GTK_NOTEBOOK(widgets.notebook_dict));
-	gtk_notebook_set_show_tabs(GTK_NOTEBOOK
-				   (widgets.notebook_dict),
-				   settings.dict_tabs);
-	gtk_notebook_set_show_border(GTK_NOTEBOOK
-				     (widgets.notebook_dict), FALSE);
-
-	label41 = gtk_label_new(_("Dict/Lex"));
-	gtk_widget_show(label41);
-
-	gtk_notebook_set_tab_label(GTK_NOTEBOOK
-				   (widgets.workbook_lower),
-				   gtk_notebook_get_nth_page
-				   (GTK_NOTEBOOK
-				    (widgets.workbook_lower),
-				    page_num), label41);
-	gtk_notebook_set_menu_label_text(GTK_NOTEBOOK
-					 (widgets.
-					  workbook_lower),
-					 gtk_notebook_get_nth_page
-					 (GTK_NOTEBOOK
-					  (widgets.
-					   workbook_lower),
-					  page_num), _("Dict/Lex"));
-	++page_num;
+	 * dict/lex
+         */
+	widgets.box_dict = gui_create_dictionary_pane();        
+        /*gtk_container_add(GTK_CONTAINER(widgets.workbook_lower),
+			  widgets.box_dict);*/
+	gtk_paned_pack2(GTK_PANED(widgets.vpaned),
+			widgets.box_dict, TRUE, TRUE);
 	/*
-	 * end  dict/lex  
+	 * end  dict/lex
 	 */
 
 	/*
-	 * gbs notebook 
+	 * gbs notebook
 	 */
 
-	widgets.notebook_gbs = gtk_notebook_new();
+/*	widgets.notebook_gbs = gtk_notebook_new();
 	gtk_widget_show(widgets.notebook_gbs);
 	gtk_container_add(GTK_CONTAINER(widgets.workbook_lower),
 			  widgets.notebook_gbs);
@@ -831,98 +599,11 @@ void create_mainwindow(void)
 	gtk_notebook_popup_enable(GTK_NOTEBOOK(widgets.notebook_gbs));
 	gtk_notebook_set_show_border(GTK_NOTEBOOK
 				     (widgets.notebook_gbs), FALSE);
-
-	label185 = gtk_label_new(_("Books"));
-	gtk_widget_show(label185);
-	gtk_notebook_set_tab_label(GTK_NOTEBOOK
-				   (widgets.workbook_lower),
-				   gtk_notebook_get_nth_page
-				   (GTK_NOTEBOOK
-				    (widgets.workbook_lower),
-				    page_num), label185);
-	gtk_notebook_set_menu_label_text(GTK_NOTEBOOK
-					 (widgets.
-					  workbook_lower),
-					 gtk_notebook_get_nth_page
-					 (GTK_NOTEBOOK
-					  (widgets.
-					   workbook_lower),
-					  page_num), _("Books"));
-	++page_num;
+*/	
 	/*
-	 * end gbs 
+	 * end gbs
 	 */
 
-	/*
-	 * percomm 
-	 */
-	if (!settings.use_percomm_dialog) {
-		gui_percomm_in_workbook(widgets.workbook_lower,
-					page_num);
-		++page_num;
-	}
-
-	/*
-	 * studypad editor 
-	 */
-	if (settings.use_studypad) {
-		if (!settings.use_studypad_dialog) {
-			settings.studypad_dialog_exist = FALSE;
-			gui_open_studypad(widgets.
-					  workbook_lower,
-					  settings.
-					  studypadfilename, page_num);
-			++page_num;
-		}
-	}
-	/*
-	 * end studypad editor 
-	 */
-
-	/*
-	 * parallel page 
-	 */
-/*
-	widgets.frame_parallel = gtk_frame_new(NULL);
-	gtk_widget_show(widgets.frame_parallel);
-	gtk_container_add(GTK_CONTAINER(widgets.workbook_lower),
-			  widgets.frame_parallel);
-
-	swInt = gtk_scrolled_window_new(NULL, NULL);
-	gtk_widget_show(swInt);
-	gtk_container_add(GTK_CONTAINER(widgets.frame_parallel),
-			  swInt);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swInt),
-				       GTK_POLICY_AUTOMATIC,
-				       GTK_POLICY_ALWAYS);
-
-	settings.dockedInt = TRUE;
-
-	widgets.html_parallel = gtk_html_new();
-	gtk_widget_show(widgets.html_parallel);
-	gtk_html_load_empty(GTK_HTML(widgets.html_parallel));
-	gtk_container_add(GTK_CONTAINER(swInt),
-			  widgets.html_parallel);
-
-
-	label197 = gtk_label_new(_("Parallel View"));
-	gtk_widget_show(label197);
-	gtk_notebook_set_tab_label(GTK_NOTEBOOK(widgets.workbook_lower),
-				   gtk_notebook_get_nth_page
-				   (GTK_NOTEBOOK
-				    (widgets.workbook_lower), page_num),
-				   label197);
-	gtk_notebook_set_menu_label_text(GTK_NOTEBOOK
-					 (widgets.workbook_lower),
-					 gtk_notebook_get_nth_page
-					 (GTK_NOTEBOOK
-					  (widgets.workbook_lower),
-					  page_num), _("Parallel View"));
-	settings.parallel_page = page_num;
-*/
-	/*
-	 * end parallel page 
-	 */
 
 	widgets.appbar = gnome_appbar_new(FALSE, TRUE,
 					  GNOME_PREFERENCES_NEVER);
@@ -931,25 +612,6 @@ void create_mainwindow(void)
 
 	gui_install_menu_hints(widgets.app);
 
-	/*
-	 * create pixmaps for ctrees
-	 */
-
-	/* added to stop annoying gdk warning on startup */
-	gtk_widget_realize(widgets.app);
-	/* when these pixmaps are created */
-	pixmap1 =
-	    gdk_pixmap_create_from_xpm_d(widgets.app->window,
-					 &mask1, &transparent,
-					 book_closed_xpm);
-	pixmap2 =
-	    gdk_pixmap_create_from_xpm_d(widgets.app->window,
-					 &mask2, &transparent,
-					 book_open_xpm);
-	pixmap3 =
-	    gdk_pixmap_create_from_xpm_d(widgets.app->window,
-					 &mask3, &transparent,
-					 mini_page_xpm);
 
 	g_signal_connect(GTK_OBJECT(widgets.app), "destroy",
 			   G_CALLBACK(on_mainwindow_destroy), NULL);
@@ -972,14 +634,6 @@ void create_mainwindow(void)
 			   (epaned_button_release_event),
 			   (gchar *) "hpaned1");
 
-/*
-	g_signal_connect(GTK_OBJECT(widgets.html_parallel),
-			   "on_url", G_CALLBACK(gui_url),
-			   (gpointer) widgets.app);
-	g_signal_connect(GTK_OBJECT(widgets.html_parallel),
-			   "link_clicked",
-			   G_CALLBACK(gui_link_clicked), NULL);
-*/
 	gtk_widget_grab_focus(nav_bar.lookup_entry);
 
 	gtk_widget_set_size_request(widgets.app, settings.gs_width,
