@@ -25,6 +25,7 @@
 
 #include <gnome.h>
 #include <gtkhtml/gtkhtml.h>
+#include <gtkhtml/htmlengine.h>
 #include <gal/shortcut-bar/e-shortcut-bar.h>
 #include <gal/shortcut-bar/e-vscrolled-bar.h>
 #include <gal/widgets/e-unicode.h>
@@ -43,14 +44,17 @@
 #include "gui/widgets.h"
 #include "gui/html.h"
 
-#include "main/shortcutbar.h"
+
+#include "main/url.h"
 #include "main/sword.h"
-#include "main/gbs.h"
 #include "main/settings.h"
 #include "main/lists.h"
 #include "main/dictlex.h"
-#include "main/module.h"
+#include "main/sidebar.h"
+#include "main/url.h"
 #include "main/xml.h"
+#include "main/module_dialogs.h"
+
 
 SIDEBAR sidebar;
 static GtkWidget *vl_html;
@@ -63,6 +67,93 @@ GList *list_of_verses;
 
 
 
+/******************************************************************************
+ * Name
+ *   get_module_from_url
+ *
+ * Synopsis
+ *   #include "gui/sidebar.h"
+ *
+ *   gchar *get_module_from_url(const gchar * url)
+ *
+ * Description
+ *   returns a module name when passed a url like:
+ *   version="KJV" passage="John 3:16"
+ *
+ * Return value
+ *   gchar*
+ */ 
+
+static gchar *get_module_from_url(const gchar * url)
+{
+	gchar *mybuf = NULL;
+	gchar *retval = NULL;
+	gchar newmod[80];
+	gint i = 0;
+	
+	mybuf = strstr(url, "version=");
+	if(mybuf != NULL) {
+		i = 0;
+		if (mybuf) {
+			mybuf = strchr(mybuf, '=');
+			++mybuf;
+			while (i < strlen(mybuf)) {
+				newmod[i] = mybuf[i];
+				newmod[i + 1] = '\0';
+				++i;
+			}
+		}
+		if (main_is_module(newmod))
+			retval = g_strdup(newmod);
+		else 
+			retval = g_strdup(xml_get_value("modules", "bible"));
+	} 
+	return retval;	
+}
+
+
+/******************************************************************************
+ * Name
+ *   get_verse_from_url
+ *
+ * Synopsis
+ *   #include "gui/sidebar.h"
+ *
+ *   gchar *get_verse_from_url(const gchar * url)
+ *
+ * Description
+ *   returns a verse reference when passed a url like:
+ *   version="KJV" passage="John 3:16"
+ *
+ * Return value
+ *   gchar*
+ */ 
+
+static gchar *get_verse_from_url(const gchar * url)
+{
+	gchar *mybuf = NULL;
+	gchar *retval = NULL;
+	gchar newref[80];
+	gint i = 0;
+	
+	mybuf = strstr(url, "passage=");
+	if(mybuf != NULL) {
+		i = 0;
+		if (mybuf) {
+			mybuf = strchr(mybuf, '=');
+			++mybuf;
+			while (i < strlen(mybuf)) {
+				newref[i] = mybuf[i];
+				newref[i + 1] = '\0';
+				++i;
+			}
+		}
+		retval = g_strdup(newref);
+	} 
+	return retval;	
+}
+
+
 /******************************************************************************
  * Name
  *   on_close_button_clicked
@@ -151,53 +242,7 @@ static void on_notebook_switch_page(GtkNotebook *notebook,
 
 static void link_clicked(GtkHTML * html, const gchar * url, gpointer data)
 {
-	gchar *mybuf = NULL;
-	gchar *buf = NULL;
-	gchar *mod_name = NULL;
-	gchar *modbuf = NULL;
-	gchar newmod[80];
-	gchar newref[80];
-	gint i = 0;
-
-	
-	if (!strncmp(url, "version=", 7)
-		 || !strncmp(url, "passage=", 7)) {
-		mybuf = strstr(url, "version=");
-		if (mybuf) {
-			mybuf = strchr(mybuf, '=');
-			++mybuf;
-			i = 0;
-			while (mybuf[i] != ' ') {
-				newmod[i] = mybuf[i];
-				newmod[i + 1] = '\0';
-				++i;
-			}
-		}
-		mybuf = NULL;
-		mybuf = strstr(url, "passage=");
-		i = 0;
-		if (mybuf) {
-			mybuf = strchr(mybuf, '=');
-			++mybuf;
-			while (i < strlen(mybuf)) {
-				newref[i] = mybuf[i];
-				newref[i + 1] = '\0';
-				++i;
-			}
-		}
-		if (check_for_module(newmod)) {
-			modbuf = newmod;
-		} else {
-			modbuf = xml_get_value("modules", "bible");	//settings.MainWindowModule;
-		}
-		buf = g_strdup(newref);
-		mod_name = g_strdup(modbuf);
-		gui_change_module_and_key(mod_name, buf);
-		g_free(buf);
-		g_free(mod_name);
-
-	} 	
-	
+	main_url_handler(url, TRUE);
 }
 
 
@@ -274,7 +319,7 @@ void gui_display_devotional_in_sidebar(void)
 				    (sidebar.optionmenu1), 4);*/
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_sidebar),
 			      4);
-	gui_display_dictlex_in_sidebar(settings.devotionalmod, buf);
+	main_sidebar_display_dictlex(settings.devotionalmod, buf);
 }
 
 
@@ -374,190 +419,6 @@ void gui_sidebar_showhide(void)
 	}
 }
 
-/******************************************************************************
- * Name
- *   gui_display_dictlex_in_sidebar
- *
- * Synopsis
- *   #include "gui/sidebar.h"
- *
- *   gboolean gui_display_dictlex_in_sidebar(char *mod_name, char *key)
- *
- * Description
- *
- *
- * Return value
- *   gboolean
- */
-
-gboolean gui_display_dictlex_in_sidebar(char *mod_name, char *key)
-{
-	if (settings.showshortcutbar) {
-		gchar *text;
-		/*gtk_option_menu_set_history(GTK_OPTION_MENU
-					    (sidebar.optionmenu1), 4);*/
-		gtk_notebook_set_current_page(GTK_NOTEBOOK
-				      (widgets.notebook_sidebar), 4);
-		text = get_dictlex_text(mod_name, key);
-		if (text) {
-			entry_display(sidebar.html_viewer_widget,
-				      mod_name, text, key, TRUE);
-			free(text);
-			return TRUE;
-		}
-	}
-	return FALSE;
-}
-
-/******************************************************************************
- * Name
- *
- *
- * Synopsis
- *   #include "gui/sidebar.h"
- *
- *   void verse_list_link_clicked(GtkHTML * html, const gchar * url,
- *				    SB_VIEWER * sv)
- *
- * Description
- *
- *
- * Return value
- *   void
- */
-
-static void verse_list_link_clicked(GtkHTML * html, const gchar * url,
-				    gpointer data)
-{
-	int type;
-	gchar *text = NULL;
-
-	type = get_mod_type(s_module_name);
-	switch (type) {
-	case TEXT_TYPE:
-		chapter_display(sidebar.htmlshow, sidebar.mod_name,
-				NULL, (gchar *) url, FALSE);
-		break;
-	case COMMENTARY_TYPE:
-	case DICTIONARY_TYPE:
-		text = get_module_text(4, s_module_name, (gchar *) url);
-		if (text) {
-			entry_display(sidebar.htmlshow, s_module_name,
-				      text, (gchar *) url, TRUE);
-			free(text);
-		}
-
-		break;
-	default:
-		break;
-	}
-
-	if (settings.showinmain)
-		gui_change_verse((gchar *) url);
-}
-
-
-/******************************************************************************
- * Name
- *
- *
- * Synopsis
- *   #include "gui/sidebar.h"
- *
- *   void gui_display_verse_list_in_sidebar(gchar * key, gchar * module_name,
- *				       gchar * verse_list)
- *
- * Description
- *
- *
- * Return value
- *   void
- */
-
-void gui_display_verse_list_in_sidebar(gchar * key, gchar * module_name,
-				       gchar * verse_list)
-{
-	GList *tmp = NULL;
-	gboolean oddkey = TRUE;
-	gchar buf[256], *utf8str, *colorkey;
-	gchar *first_key = NULL;
-	gchar *next_verse = NULL;
-	gint i = 0;
-	gint count = 0;
-	GString *str;
-	GtkTreeModel *model;
-	GtkListStore *list_store;	
-	GtkTreeSelection *selection;
-	GtkTreePath *path;
-	GtkTreeIter iter;
-	RESULTS *list_item;
-	
-	
-	list_of_verses = g_list_first(list_of_verses);
-	if(list_of_verses) {
-		while(list_of_verses) {
-			g_free(list_of_verses->data);
-			list_of_verses = g_list_next(list_of_verses);
-		}
-		g_list_free(list_of_verses);
-	}
-	list_of_verses = NULL;
-	
-	strcpy(settings.sb_search_mod,module_name);
-	
-	model = gtk_tree_view_get_model(GTK_TREE_VIEW(sidebar.results_list));
-	list_store = GTK_LIST_STORE(model);
-	gtk_list_store_clear(list_store);
-	
-	strcpy(sidebar.mod_name, module_name);
-	
-	if (verse_list[0] == 'S' && verse_list[1] == 'e'
-	    && verse_list[2] == 'e') {
-		verse_list += 4;
-	}
-	i = 0;
-	
-	count = start_parse_verse_list(verse_list,key);
-	while (count--) {
-		next_verse = get_next_verse_list_element(i++);
-		if (!next_verse)
-			break;
-		list_item = g_new(RESULTS,1);
-		list_item->module = module_name;
-		list_item->key = (gchar *) next_verse;
-		list_of_verses = g_list_append(list_of_verses, 
-						(RESULTS *) list_item);
-	}
-	tmp = list_of_verses;
-	while (tmp != NULL) {
-		list_item = (RESULTS *) tmp->data;
-		gtk_list_store_append(list_store, &iter);
-		gtk_list_store_set(list_store, &iter, 0,
-					   (const char *) list_item->key, -1);
-		
-		if (i == 0)
-			first_key = g_strdup((const char *) list_item->key);
-		++i;
-		tmp = g_list_next(tmp);
-	}
-	
-	selection = gtk_tree_view_get_selection
-                                          (GTK_TREE_VIEW(sidebar.results_list));
-	if(!gtk_tree_model_get_iter_first(model,&iter))
-		return;
-	path = gtk_tree_model_get_path(model,&iter);				
-	gtk_tree_selection_select_path(selection,
-                                             path);
-
-	gtk_tree_path_free(path);
-	
-	gui_verselist_button_release_event(NULL,NULL,NULL);
-	/*gtk_option_menu_set_history(GTK_OPTION_MENU
-				    (sidebar.optionmenu1), 3);*/
-	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_sidebar),
-			      3);
-	//g_string_free(str, TRUE);
-}
 
 
 /******************************************************************************
@@ -754,95 +615,49 @@ static gboolean on_modules_list_button_release(GtkWidget * widget,
 						   gpointer user_data)
 {
 	GtkTreeSelection * selection;
-	gint sbtype;
 	GtkTreeIter selected;
-	gchar *mod = NULL;
-	gint mod_type;
 	GtkTreeModel *model;
+	gchar *mod = NULL;
 	
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(sidebar.module_list));
-	model = gtk_tree_view_get_model(GTK_TREE_VIEW(sidebar.module_list));
 	
-	if (!gtk_tree_selection_get_selected(selection, NULL, &selected))
-		return FALSE;
-	if (gtk_tree_model_iter_has_child(GTK_TREE_MODEL(model), &selected))
-		return FALSE;
-	gtk_tree_model_get(GTK_TREE_MODEL(model), &selected, 0, &mod, -1);
+	if (!gtk_tree_selection_get_selected(selection, &model, &selected))
+		return FALSE;	
+	
+	gtk_tree_model_get(GTK_TREE_MODEL(model), &selected, 
+				3, &mod, 
+				-1);
 
-	if (!mod)
-		return FALSE;
+	
 	
 	button_mod_list = 1;
 
 	switch (event->button) {
 	case 1:
+		main_mod_treeview_button_one(model, selected);
 		button_mod_list = 1;
 		break;
 	case 2:
-		button_mod_list = 2;
+		if (mod) {
+			if (!g_utf8_collate(mod, _("Parallel View"))) {
+				g_free(mod);
+				return FALSE;
+			}
+			gui_open_module_in_new_tab(mod);
+		}
 		break;
 	case 3:
-		if (!g_utf8_collate(mod, _("Parallel View"))) {
-			g_free(mod);
-			return FALSE;
+		if (mod) {
+			if (!g_utf8_collate(mod, _("Parallel View"))) {
+				g_free(mod);
+				return FALSE;
+			}
+			buf_module = g_strdup(mod);
+			gtk_menu_popup(GTK_MENU
+				       (sidebar.menu_modules),
+				       NULL, NULL, NULL, NULL,
+				       0, gtk_get_current_event_time());
 		}
-		buf_module = g_strdup(mod);
-		gtk_menu_popup(GTK_MENU
-			       (sidebar.menu_modules),
-			       NULL, NULL, NULL, NULL,
-			       0, gtk_get_current_event_time());
-		return FALSE;
-			
-		break;
-	}
-	
-	
-	if (!g_utf8_collate(mod, _("Parallel View"))) 
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
-					     (widgets. button_parallel_view),
-					     TRUE);
-	
-	
-	sbtype = get_mod_type(mod);
-	switch (sbtype) {
-	case 0:
-		if(button_mod_list == 2) {
-			gui_open_bibletext_dialog(mod);
-			break;
-		}
-		if (GTK_TOGGLE_BUTTON(widgets.button_parallel_view)->
-		    active) {
-			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
-						     (widgets.
-						      button_parallel_view),
-						     FALSE);
-		}
-		gui_change_module_and_key(mod, settings.currentverse);
-		break;
-	case 1:
-		if(button_mod_list == 2) {
-			gui_open_commentary_dialog(mod);
-			break;
-		}
-		gui_change_module_and_key(mod, settings.currentverse);
-		break;
-	case 2:
-		if(button_mod_list == 2) {
-			gui_open_dictlex_dialog(mod);
-			break;
-		}
-		gtk_notebook_set_current_page
-		    (GTK_NOTEBOOK(widgets.workbook_lower), 0);
-		gui_change_module_and_key(mod, settings.dictkey);
-		break;
-	case 3:
-		if(button_mod_list == 2) {
-			gui_open_gbs_dialog(mod);
-			break;
-		}
-		gtk_notebook_set_current_page
-		    	(GTK_NOTEBOOK(widgets.workbook_lower), 1);
-		gui_change_module_and_key(mod, NULL);
 		break;
 	}
 	g_free(mod);
@@ -896,7 +711,7 @@ gboolean gui_verselist_button_release_event(GtkWidget * widget,
 			//gui_change_module_and_key(settings.sb_search_mod, key);
 			break;
 		case 2:
-			gui_change_module_and_key(settings.sb_search_mod, key);
+			gui_open_passage_in_new_tab(key);
 			break;
 		case 3:
 	
@@ -905,10 +720,10 @@ gboolean gui_verselist_button_release_event(GtkWidget * widget,
 			break;
 		}
 	}
-	text = get_search_results_text(settings.sb_search_mod, key);
+	text = main_get_search_results_text(settings.sb_search_mod, key);
 	if (text) {
 		settings.displaySearchResults = TRUE;
-		entry_display(sidebar.html_widget,
+		main_entry_display(sidebar.html_widget,
 			      settings.sb_search_mod, text, key, TRUE);
 		settings.displaySearchResults = FALSE;
 		free(text);
@@ -957,6 +772,39 @@ static gboolean on_treeview_button_press_event(GtkWidget * widget,
 }
 
 
+/******************************************************************************
+ * Name
+ *   vpaned_srch_rslt_button_release_event
+ *
+ * Synopsis
+ *   #include "gui/sidebar.h"
+ *
+ *   gboolean vpaned_srch_rslt_button_release_event(GtkWidget *widget,
+ *                           GdkEventButton  *event, gpointer user_data)
+ *
+ * Description
+ *   This function is called when the pane in the search result window is
+ *   resized.  It saves the position in the settings.
+ *
+ * Return value
+ *   gboolean
+ */
+
+gboolean vpaned_srch_rslt_button_release_event(GtkWidget * widget,
+					       GdkEventButton * event,
+					       gpointer user_data)
+{
+	gint panesize;
+	gchar layout[80];
+
+	panesize = gtk_paned_get_position(GTK_PANED(widget));
+
+	settings.verselist_toppane_height = panesize;
+	sprintf(layout, "%d", settings.verselist_toppane_height);
+	xml_set_value("GnomeSword", "layout", "vltoppaneheight", layout);
+}
+
+
 /******************************************************************************
  * Name
  *   on_save_list_as_bookmarks_activate
@@ -974,7 +822,7 @@ static gboolean on_treeview_button_press_event(GtkWidget * widget,
  *   void
  */
 
-void on_save_list_as_bookmarks_activate(GtkMenuItem * menuitem,
+static void on_save_list_as_bookmarks_activate(GtkMenuItem * menuitem,
 					gpointer user_data)
 {
 	gui_verselist_to_bookmarks(list_of_verses);
@@ -997,31 +845,35 @@ void on_save_list_as_bookmarks_activate(GtkMenuItem * menuitem,
  *   void
  */
 
-void on_open_in_dialog_activate(GtkMenuItem * menuitem, gpointer user_data)
+static void on_open_in_dialog_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
-	gint module_type;
-
-	module_type = get_mod_type(buf_module);
-	switch (module_type) {
-	case -1:
-		break;
-	case TEXT_TYPE:
-		gui_open_bibletext_dialog(buf_module);
-		break;
-	case COMMENTARY_TYPE:
-		gui_open_commentary_dialog(buf_module);
-		break;
-	case DICTIONARY_TYPE:
-		gui_open_dictlex_dialog(buf_module);
-		break;
-	case BOOK_TYPE:
-		gui_open_gbs_dialog(buf_module);
-		break;
-	}
+	main_dialogs_open(buf_module);
 	g_free(buf_module);
 }
 
 
+/******************************************************************************
+ * Name
+ *   on_open_in_tab_activate
+ *
+ * Synopsis
+ *   #include "gui/sidebar.h"
+ *
+ *   void on_open_in_tab_activate(GtkMenuItem * menuitem, gpointer user_data)
+ *
+ * Description
+ *
+ *
+ * Return value
+ *   void
+ */
+
+static void on_open_in_tab_activate(GtkMenuItem * menuitem, gpointer user_data)
+{
+	gui_open_module_in_new_tab(buf_module);
+}
+
+
 /******************************************************************************
  * Name
  *   on_about2_activate
@@ -1038,7 +890,7 @@ void on_open_in_dialog_activate(GtkMenuItem * menuitem, gpointer user_data)
  *   void
  */
 
-void on_about2_activate(GtkMenuItem * menuitem, gpointer user_data)
+static void on_about2_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
 	gui_display_about_module_dialog(buf_module, FALSE);
 	g_free(buf_module);
@@ -1085,6 +937,12 @@ GtkWidget *create_results_menu(void)
 }
 
 static GnomeUIInfo menu_modules_uiinfo[] = {
+	{
+	 GNOME_APP_UI_ITEM, N_("Open in a new tab"),
+	 N_("Open selected module in a new tab"),
+	 (gpointer) on_open_in_tab_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_FILENAME, PACKAGE_PIXMAPS_DIR "/new_tab_button.png",
+	 0, (GdkModifierType) 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Open in dialog"),
 	 N_("Open selected module in a dialog"),
@@ -1126,6 +984,104 @@ GtkWidget *create_menu_modules(void)
 	return menu_modules;
 }
 
+
+/******************************************************************************
+ * Name
+ *  on_button_release_event
+ *
+ * Synopsis
+ *   #include "_bibletext.h"
+ *
+ *  gboolean on_button_release_event(GtkWidget * widget,
+			    GdkEventButton * event, DIALOG_DATA * t)	
+ *
+ * Description
+ *   called when mouse button is clicked in html widget
+ *
+ * Return value
+ *   gboolean
+ */
+
+static gboolean on_button_release_event(GtkWidget * widget,
+					GdkEventButton * event,
+					gpointer data)
+{	
+	gchar *key;
+	const gchar *url;
+	gchar *buf = NULL;
+	
+	switch (event->button) {
+	case 1:		
+		break;
+	case 2:		
+		url = html_engine_get_link_at (GTK_HTML(data)->engine,
+					 event->x,
+					 event->y);
+		if(url && strstr(url,"sword://")) {
+			gchar **work_buf = g_strsplit (url,"/",4);			
+			gui_open_passage_in_new_tab(work_buf[KEY]);
+			g_strfreev(work_buf);
+		}			
+		break;
+	case 3:
+		break;
+	}
+	return FALSE;
+}
+
+
+static void tree_selection_changed_cb (GtkTreeSelection *selection, gpointer data)
+{
+	gui_verselist_button_release_event(NULL,
+					   NULL,
+					   NULL);
+}
+static gboolean tree_key_press_cb(GtkWidget *widget, GdkEventKey *event,
+                                            gpointer user_data)
+{
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter selected;
+	gchar *key = NULL;
+	gchar *url = NULL;
+
+
+	selection =
+	    gtk_tree_view_get_selection((GtkTreeView *) sidebar.results_list);
+	model =
+	    gtk_tree_view_get_model(GTK_TREE_VIEW(sidebar.results_list));
+	if (!gtk_tree_selection_get_selected(selection, NULL, &selected))
+		return FALSE;
+
+	gtk_tree_model_get(GTK_TREE_MODEL(model), &selected, 0, &key,
+			   -1);
+	if (!key)
+		return FALSE;
+	url = g_strdup_printf("sword://%s/%s",settings.sb_search_mod,key);
+
+	g_warning("%d",event->keyval);
+	if(event) {
+		switch (event->keyval) {
+		case 65293: 
+		case 65421: 
+			main_url_handler(url,TRUE);
+			break;
+		case 32:
+			gui_open_passage_in_new_tab(key);
+			break;
+		/*case :
+	
+			break;*/
+		default:
+			break;
+		}
+	}
+	free(key);
+	return FALSE;	
+	
+}
+
+
 /******************************************************************************
  * Name
  *   create_search_results_page
@@ -1153,7 +1109,7 @@ static void create_search_results_page(GtkWidget * notebook)
 	GtkWidget *frame4;
 	GtkWidget *scrolledwindow4;
 	GtkListStore *model;
-	GObject *selection;
+	GtkTreeSelection *selection;
 	GtkWidget *menu = create_results_menu();
 
 	vbox = gtk_vbox_new(FALSE, 0);
@@ -1163,7 +1119,10 @@ static void create_search_results_page(GtkWidget * notebook)
 	gtk_widget_show(vpaned_srch_rslt);
 	gtk_box_pack_start(GTK_BOX(vbox), vpaned_srch_rslt, TRUE,
 			   TRUE, 0);
-	gtk_paned_set_position(GTK_PANED(vpaned_srch_rslt), 100);
+	if (settings.verselist_toppane_height == 0)
+		settings.verselist_toppane_height = 100;
+	gtk_paned_set_position(GTK_PANED(vpaned_srch_rslt),
+				settings.verselist_toppane_height);
 
 	frame3 = gtk_frame_new(NULL);
 	gtk_widget_show(frame3);
@@ -1194,13 +1153,14 @@ static void create_search_results_page(GtkWidget * notebook)
 					  FALSE);
 	add_columns(GTK_TREE_VIEW(sidebar.results_list));
 
-	selection = G_OBJECT(gtk_tree_view_get_selection
-			     (GTK_TREE_VIEW(sidebar.results_list)));
+	selection = gtk_tree_view_get_selection
+			     (GTK_TREE_VIEW(sidebar.results_list));
 
 	frame4 = gtk_frame_new(NULL);
 	gtk_widget_show(frame4);
 	gtk_paned_pack2(GTK_PANED(vpaned_srch_rslt), frame4, TRUE,
 			TRUE);
+//	gtk_widget_set_size_request (frame4, 100, -1);
 
 	gnome_popup_menu_attach(menu, sidebar.results_list, NULL);
 	gnome_app_install_menu_hints(GNOME_APP(widgets.app),
@@ -1220,10 +1180,22 @@ static void create_search_results_page(GtkWidget * notebook)
 			  sidebar.html_widget);
 	gtk_html_load_empty(GTK_HTML(sidebar.html_widget));
 
+	g_signal_connect((gpointer)sidebar.results_list, 
+			 "key_press_event",
+			 G_CALLBACK(tree_key_press_cb),
+			 NULL);
+	g_signal_connect((gpointer)selection, 
+			 "changed",
+			 G_CALLBACK(tree_selection_changed_cb),
+			 NULL);
 	g_signal_connect(GTK_OBJECT(sidebar.html_widget), 
 			 "link_clicked",
 			 G_CALLBACK(link_clicked),
 			 NULL);
+	g_signal_connect((gpointer) sidebar.html_widget,
+			 "button_release_event",
+			 G_CALLBACK(on_button_release_event),
+			 sidebar.html_widget);
 
 	g_signal_connect((gpointer) sidebar.results_list,
 			 "button_release_event",
@@ -1233,6 +1205,10 @@ static void create_search_results_page(GtkWidget * notebook)
 			 "button_press_event",
 			 G_CALLBACK(on_treeview_button_press_event),
 			 NULL);
+	g_signal_connect(GTK_OBJECT(vpaned_srch_rslt),
+			"button_release_event",
+			G_CALLBACK(vpaned_srch_rslt_button_release_event),
+			NULL);
 }
 
 
@@ -1341,7 +1317,8 @@ static void menu_deactivate_callback (GtkWidget *widget, gpointer user_data)
 
 static GnomeUIInfo menu_uiinfo[] = {
 	{
-	 GNOME_APP_UI_ITEM, N_("_Modules"),
+	 GNOME_APP_UI_ITEM, 
+	 N_("_Modules"),
 	 NULL,
 	 (gpointer) on_modules_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK,
@@ -1352,8 +1329,8 @@ static GnomeUIInfo menu_uiinfo[] = {
 	 N_("_Bookmarks"), NULL,
 	 (gpointer) on_bookmarks_activate,
 	 NULL,
-	 NULL, GNOME_APP_PIXMAP_STOCK,
-	 "epiphany-bookmarks", 0,
+	 NULL, GNOME_APP_PIXMAP_FILENAME,
+	 PACKAGE_PIXMAPS_DIR"/epiphany-bookmarks.png", 0,
 	 (GdkModifierType) 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM,
@@ -1399,7 +1376,7 @@ static GnomeUIInfo menu_uiinfo[] = {
  *   GtkWidget* create_menu(void)
  *
  * Description
- *
+ *   main sidebar menu 
  *
  * Return value
  *   GtkWidget*
@@ -1458,32 +1435,18 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 	GtkWidget *close_button;
 	GtkWidget *image;
 	GtkWidget *shortcut_box;
-	GObject *mod_selection;
+	GtkCellRenderer *renderer;
+	GtkTreeViewColumn *column;
 
 	vbox1 = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox1);
 	gtk_paned_pack1(GTK_PANED(paned), vbox1, FALSE, TRUE);
 	widgets.shortcutbar = vbox1;
 
-	
-	/*gtk_option_menu_new();
-	gtk_widget_show(sidebar.optionmenu1);
-	gtk_box_pack_start(GTK_BOX(vbox1), sidebar.optionmenu1, FALSE,
-			   TRUE, 0);
-
-	menu1 = gtk_menu_new();
-	gnome_app_fill_menu(GTK_MENU_SHELL(menu1), menu_uiinfo,
-			    NULL, FALSE, 0);
-
-	gtk_option_menu_set_menu(GTK_OPTION_MENU(sidebar.optionmenu1),
-				 menu1);
-*/
 	frame = gtk_frame_new (NULL);
 	gtk_widget_show (frame);
 	gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
 	
-	//gtk_frame_set_shadow_type(GTK_FRAME(frame),GTK_SHADOW_NONE);
-	
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (hbox);
 	gtk_container_add (GTK_CONTAINER (frame), hbox);
@@ -1551,8 +1514,6 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 	GTK_WIDGET_UNSET_FLAGS(widgets.notebook_sidebar, GTK_CAN_FOCUS);
 	gtk_notebook_set_show_tabs(GTK_NOTEBOOK
 				   (widgets.notebook_sidebar), FALSE);
-	/*gtk_notebook_set_scrollable(GTK_NOTEBOOK
-				    (widgets.notebook_sidebar), TRUE);*/
 	gtk_notebook_set_show_border(GTK_NOTEBOOK
 				     (widgets.notebook_sidebar), FALSE);
 
@@ -1574,8 +1535,9 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 			  sidebar.module_list);
 	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW
 					  (sidebar.module_list), FALSE);
-
-
+	main_create_pixbufs();
+	main_add_mod_tree_columns(GTK_TREE_VIEW(sidebar.module_list));
+	
 	scrolledwindow_bm = gtk_scrolled_window_new(NULL, NULL);
 	gtk_widget_show(scrolledwindow_bm);
 	gtk_container_add(GTK_CONTAINER(widgets.notebook_sidebar),
@@ -1595,15 +1557,10 @@ GtkWidget *gui_create_sidebar(GtkWidget * paned)
 
 	create_search_results_page(widgets.notebook_sidebar);
 	create_viewer_page(widgets.notebook_sidebar);
-/*
-	vbox_viewer = gtk_vbox_new(FALSE, 0);
-	gtk_widget_show(vbox_viewer);
-	gtk_container_add(GTK_CONTAINER(widgets.notebook_sidebar),
-			  vbox_viewer);
-*/
-	gui_load_module_tree(sidebar.module_list, TRUE);
+	
+	main_load_module_tree(sidebar.module_list);
 		     
-	g_signal_connect((gpointer) sidebar.module_list,
+	g_signal_connect_after((gpointer) sidebar.module_list,
 			 "button_release_event",
 			 G_CALLBACK(on_modules_list_button_release),
 			 NULL);
