@@ -36,7 +36,7 @@
 #include "gui/editor_spell.h"
 #include "gui/studypad.h"
 #include "gui/html.h"
-#include "gui/percomm.h"
+//#include "gui/percomm.h"
 #include "gui/commentary_dialog.h"
 #include "gui/fileselection.h"
 #include "gui/editor_menu.h"
@@ -44,6 +44,7 @@
 
 #include "main/settings.h"
 #include "main/percomm.h"
+#include "main/module_dialogs.h"
 
 static void on_btn_save_clicked(GtkButton * button,
 				GSHTMLEditorControlData * ecd);
@@ -154,11 +155,7 @@ static void on_btn_save_clicked(GtkButton * button,
 				GSHTMLEditorControlData * ecd)
 {
 	gchar *filename = NULL;
-	if (ecd->personal_comments) {
-		gui_save_note(ecd);
-		ecd->changed = FALSE;
-		gui_update_statusbar(ecd);
-	} else if (ecd->studypad) {
+	if (ecd->studypad) {
 		if(settings.studypadfilename) {
 			if (strlen(settings.studypadfilename) > 0) {
 				filename = g_strdup(settings.studypadfilename);
@@ -194,10 +191,11 @@ static void on_btn_save_clicked(GtkButton * button,
 static void on_btn_delete_clicked(GtkButton * button,
 				  GSHTMLEditorControlData * ecd)
 {
-	if (ecd->personal_comments) {
+/*	if (ecd->personal_comments) {
 		GS_DIALOG *info;
 		gint test;
 		GString *str;
+		gchar *url = NULL;
 		
 		str = g_string_new("");
 		info = gui_new_dialog();
@@ -211,11 +209,12 @@ static void on_btn_delete_clicked(GtkButton * button,
 
 		test = gui_alert_dialog(info);
 		if (test == GS_YES) {
-			delete_percomm_note();
-			if(settings.use_percomm_dialog)
-				gui_display_commentary_in_dialog(ecd->key);
-			else
-				gui_display_percomm(ecd->key);
+			main_dialog_delete_note();
+			url = g_strdup_printf(	"sword://%s/%s",
+						ecd->filename,
+						ecd->key);
+			main_dialog_goto_bookmark(url);
+			g_free(url);
 		}
 		settings.percomverse = ecd->key;
 		ecd->changed = FALSE;
@@ -223,6 +222,7 @@ static void on_btn_delete_clicked(GtkButton * button,
 		g_free(info);
 		g_string_free(str,TRUE);
 	}
+	*/
 
 }
 
