@@ -36,10 +36,14 @@
 
 #include "main/settings.h"
 
+static void toolbar_update_format(GSHTMLEditorControlData * cd);
+
+
 static struct {
 	GtkHTMLParagraphStyle style;
 	const gchar *description;
-} paragraph_style_items[] = {
+} 
+paragraph_style_items[] = {
 	{ GTK_HTML_PARAGRAPH_STYLE_NORMAL, N_("Normal") },
 	{ GTK_HTML_PARAGRAPH_STYLE_PRE, N_("Preformat") },
 	{ GTK_HTML_PARAGRAPH_STYLE_ITEMDOTTED, N_("Bulleted List") },
@@ -55,6 +59,8 @@ static struct {
 	{ GTK_HTML_PARAGRAPH_STYLE_ADDRESS, N_("Address") },
 	{ GTK_HTML_PARAGRAPH_STYLE_NORMAL, NULL },
 };
+
+
 /******************************************************************************
  * Name
  *   paragraph_style_changed_cb
@@ -458,6 +464,7 @@ static void set_color_combo(GtkHTML * html,
 			      &html_colorset_get_color_allocated
 			      (html->engine->painter,
 			       HTMLTextColor)->color);
+
 }
 
 /******************************************************************************
@@ -529,7 +536,7 @@ static void load_done(GtkHTML * html, GSHTMLEditorControlData * cd)
 static GtkWidget *setup_color_combo(GSHTMLEditorControlData * cd)
 {
 	HTMLColor *color;
-
+ 
 	color = html_colorset_get_color (cd->html->engine->settings->color_set, HTMLTextColor);
 	if (GTK_WIDGET_REALIZED (cd->html))
 		html_color_alloc (color, cd->html->engine->painter);
@@ -1125,7 +1132,7 @@ static GtkWidget *create_style_toolbar(GSHTMLEditorControlData * cd)
 	coloritem = setup_color_combo(cd);
 	gtk_toolbar_append_widget(GTK_TOOLBAR(cd->toolbar_style),
 				  coloritem, NULL, NULL);
-
+ 
 	cd->font_style_changed_connection_id
 	    =
 	    g_signal_connect(G_OBJECT(cd->htmlwidget),
@@ -1222,7 +1229,7 @@ static void toolbar_item_update_sensitivity(GtkWidget * widget,
  *   void
  */
 
-void toolbar_update_format(GSHTMLEditorControlData * cd)
+static void toolbar_update_format(GSHTMLEditorControlData * cd)
 {
 	/*if (cd->toolbar_style)
 		gtk_container_forall(GTK_CONTAINER(cd->toolbar_style),
