@@ -27,12 +27,11 @@
 
 extern GSHTMLEditorControlData *editor_cd;
 
-void gui_studypad_can_close(GSHTMLEditorControlData *ecd);
+void gui_studypad_can_close(void);
 gint save_file_program_end(GtkWidget *htmlwidget, gchar *filename);
 gint save_file(gchar *filename, GSHTMLEditorControlData *ecd);
 gint load_file(gchar *filename, GSHTMLEditorControlData *ecd);
-gint gui_open_studypad(GtkWidget *notebook, gchar * file_name, 
-						gint page_num);
+gint gui_open_studypad(gchar * file_name);
 GtkWidget *gui_create_studypad_control(GtkWidget * container,
 				gchar * filename);
 
