@@ -25,7 +25,6 @@
 #include "gui/editor.h"
 
 GtkWidget *gui_toolbar_style(GSHTMLEditorControlData *ecd);
-void toolbar_update_format(GSHTMLEditorControlData *ecd);
+//void toolbar_update_format(GSHTMLEditorControlData *ecd);
 
 #endif
-
