@@ -26,8 +26,8 @@
 extern "C" {
 #endif
 
-char *get_dictlex_key(int manager, char * module_name, int direction);	
-char *get_dictlex_text(char * mod_name, char * key);
+//char *get_dictlex_key(int manager, char * module_name, int direction);	
+//char *get_dictlex_text(char * mod_name, char * key);
 	
 #ifdef __cplusplus
 }
