@@ -25,13 +25,27 @@
 #ifdef __cplusplus
 extern "C"
 {
-#endif
-#ifdef USE_GNOME2
+#endif	
+
 #include <glib-2.0/glib.h>
-#else
-#include <glib-1.2/glib.h>
-#endif
-	
+
+typedef struct _module_lists MOD_LISTS;
+struct _module_lists {
+	GList
+	    *biblemods,
+	    *commentarymods,
+	    *dictionarymods,
+	    *bookmods,
+	    *percommods,
+	    *devotionmods,
+	    *text_descriptions,
+	    *dict_descriptions,
+	    *comm_descriptions,
+	    *book_descriptions, 
+	    *bible_books, 
+	    *options;
+};
+
 /* list types */
 #define TEXT_LIST 0 
 #define TEXT_DESC_LIST 1 
@@ -48,8 +62,8 @@ extern "C"
 
 
 GList * get_list(gint type);
-void init_lists(void);
-void shutdown_list(void);
+void main_init_lists(void);
+void main_shutdown_list(void);
 
 #ifdef __cplusplus
 }
