@@ -28,16 +28,15 @@ extern "C" {
 int save_percomm_options(char * mod_name, char * option, 
 				    int choice);
 int load_percomm_options(char * modName, char * option);
-char *get_percomm_key(char * module_name);
-char *get_percomm_text(char * key);	
-void set_percomm_key(char * key);
-void change_percomm_module(char * mod_name);
+//char *get_percomm_key(char * module_name);
+//char *get_percomm_text(char * key);	
+//void set_percomm_key(char * key);
+//void change_percomm_module(char * mod_name);
 void save_percomm_note(char *note);
 void delete_percomm_note(void);
-int is_personal_comment(char * mod_name);
+//int is_personal_comment(char * mod_name);
 #ifdef __cplusplus
 }
 #endif
 
 #endif
-
