@@ -23,16 +23,13 @@
 #include <config.h>
 #endif
 
-#ifdef USE_GNOME2
+
 #include <glib-2.0/glib.h>
-#else
-#include <glib-1.2/glib.h>
-#endif
 #include <libxml/parser.h>
 
 
 #include "main/xml.h"
-#include "main/module.h"
+#include "main/sword.h"
 #include "main/settings.h"
 
 struct _bookmark_data {
@@ -99,19 +96,23 @@ void xml_new_bookmark_file(void)
 	xml_add_bookmark_to_parent(xml_folder, 
 					"Acts 16:31",
 					"Acts 16:31",
+					NULL,
 					NULL);
 	xml_add_bookmark_to_parent(xml_folder, 
 					"Eph 2:8",
 					"Eph 2:8",
+					NULL,
 					NULL);
 	xml_add_bookmark_to_parent(xml_folder, 
 					"Romans 1:16",
 					"Romans 1:16",
+					NULL,
 					NULL);
 	xml_folder = xml_add_folder_to_parent(xml_root, "What is the Gospel?");
 	xml_add_bookmark_to_parent(xml_folder, 
 					"1 Cor 15:1-4",
 					"1 Cor 15:1",
+					NULL,
 					NULL);
 
 	xmlSaveFile(xml_filename, xml_doc);
@@ -166,16 +167,16 @@ xmlNodePtr xml_add_folder_to_parent(xmlNodePtr parent, gchar * caption)
  */
 
 void xml_add_bookmark_to_parent(xmlNodePtr parent, gchar * caption, 
-					gchar * key, gchar * module)
+			gchar * key, gchar * module, gchar * mod_desc)
 {
 	xmlNodePtr xml_node;
 	xmlAttrPtr xml_attr;
-	gchar *mod_desc = NULL;
+	//gchar *mod_desc = NULL;
 
-	if (module) {
+	/*if (module) {
 		if (strlen(module) > 2)
 			mod_desc = get_module_description(module);
-	} 
+	} */
 
 	if (mod_desc == NULL)
 		mod_desc = " ";
@@ -194,6 +195,9 @@ void xml_add_bookmark_to_parent(xmlNodePtr parent, gchar * caption,
 	xml_attr =
 	    xmlNewProp(xml_node, "description",
 		       (const xmlChar *) caption);
+	/*xml_attr =
+	    xmlNewProp(xml_node, "caption",
+		       (const xmlChar *) caption);*/
 }
 
 /******************************************************************************
@@ -238,14 +242,19 @@ static void parse_gnode_tree(GNode * node, xmlNodePtr parent)
 {
 	static xmlNodePtr cur_node;
 	GNode *work;
+	gchar *mod_desc = NULL;
 
 	for (work = node->children; work; work = work->next) {
 		get_node_data(work);
 		if (!es->is_leaf) {
 			cur_node = xml_add_folder_to_parent(parent, es->caption);
 		} else {
+			if (es->module) {
+				if (strlen(es->module) > 2)
+					mod_desc = main_get_module_description(es->module);
+			}
 			xml_add_bookmark_to_parent(parent, es->caption,
-						es->key, es->module);
+						es->key, es->module, mod_desc);
 		}
 		g_free(es);
 		parse_gnode_tree(work, cur_node);
@@ -276,6 +285,7 @@ void xml_save_gnode_to_bookmarks(GNode * gnode, gchar * file_buf)
 	xmlDocPtr root_doc;
 	xmlAttrPtr root_attr;
 	const xmlChar *xml_filename;
+	gchar *mod_desc = NULL;
 	
 	if (!gnode)
 		return;
@@ -299,10 +309,15 @@ void xml_save_gnode_to_bookmarks(GNode * gnode, gchar * file_buf)
 		    xml_add_folder_to_parent(root_node, es->caption);
 		parse_gnode_tree(gnode, cur_node);
 	} else {
+		if (es->module) {
+			if (strlen(es->module) > 2)
+				mod_desc = main_get_module_description(es->module);
+		}
 		xml_add_bookmark_to_parent(root_node, 
 						es->caption,
 						es->key,
-						es->module);
+						es->module,
+						mod_desc);
 	}
 
 	while ((gnode = g_node_next_sibling(gnode)) != NULL) {
@@ -313,11 +328,16 @@ void xml_save_gnode_to_bookmarks(GNode * gnode, gchar * file_buf)
 						     es->caption);
 			parse_gnode_tree(gnode, cur_node);
 		} else {
+			if (es->module) {
+				if (strlen(es->module) > 2)
+					mod_desc = main_get_module_description(es->module);
+			}
 			if (root_doc != NULL) {
 				xml_add_bookmark_to_parent
 				    (root_node, es->caption,
 						es->key,
-						es->module);
+						es->module,
+						mod_desc);
 			}
 		}
 	}
@@ -510,9 +530,13 @@ int xml_create_settings_file(char *path)
 	xmlNewTextChild(section_node, NULL, "morphs", "0");
 	xmlNewTextChild(section_node, NULL, "strongs", "0");
 
+	section_node = xmlNewChild(root_node, NULL, "book", NULL);
+	xmlNewTextChild(section_node, NULL, "module", NULL);
+	xmlNewTextChild(section_node, NULL, "key", NULL);
+	xmlNewTextChild(section_node, NULL, "offset", "0");
 
 	section_node = xmlNewChild(root_node, NULL, "keys", NULL);
-	xmlNewTextChild(section_node, NULL, "book", "");
+	xmlNewTextChild(section_node, NULL, "book", "0");
 	xmlNewTextChild(section_node, NULL, "dictionary", "Grace");
 	xmlNewTextChild(section_node, NULL, "verse", "Romans 8:28");
 
@@ -525,6 +549,7 @@ int xml_create_settings_file(char *path)
 	xmlNewTextChild(section_node, NULL, "textpane", "240");
 	xmlNewTextChild(section_node, NULL, "shortcutbar", "178");
 	xmlNewTextChild(section_node, NULL, "uperpane", "210");
+	xmlNewTextChild(section_node, NULL, "vltoppaneheight", "210");
 
 
 	section_node = xmlNewChild(root_node, NULL, "lexicons", NULL);
@@ -585,6 +610,7 @@ int xml_create_settings_file(char *path)
 
 
 	section_node = xmlNewChild(root_node, NULL, "tabs", NULL);
+	xmlNewTextChild(section_node, NULL, "browsing", "1");
 	xmlNewTextChild(section_node, NULL, "bible", "0");
 	xmlNewTextChild(section_node, NULL, "comm", "0");
 	xmlNewTextChild(section_node, NULL, "dict", "0");
